package org.climax.demo;

import java.io.File;
import java.util.AbstractMap;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import org.climax.ArgGroupComplete;
import org.climax.ArgParser;
import org.climax.ArgParserException;
import org.climax.ArgSeparators;
import org.climax.CLI;
import org.climax.Option;
import org.climax.OptionGroupComplete;
import org.climax.OptionType;
import org.climax.argacceptor.UnlimitedArgAcceptor;
import org.climax.argparser.IntegerArgParser;
import org.climax.argparser.ParameterlessArgParser;
import org.climax.argsvalidator.PassiveArgsValidator;
import org.climax.argsvalidator.SingleOrMultipleArgsValidator;
import org.climax.reflect.ArgGroupCompleteSpec;
import org.climax.reflect.CLIInterface;
import org.climax.reflect.CLISpec;
import org.climax.reflect.OptionCompleteSpec;
import org.climax.reflect.OptionGroupCompleteSpec;
import org.climax.reflect.Singleton;

/**
 * This demo provides a command line interface exactly like Apache Ant's 
 * command line interface and prints the results to standard output. The 
 * purpose of this demo is to provide an example of how Climax can be used 
 * to customize the help information.
 */
public final class Ant {

	/**
	 * A {@code CLI} interface for the command line interface. 
	 */
	@CLISpec(
		helpOptionGroupDocHelp = 
			"  ${format:%-22s;p=usage} print this message",			
		helpOptionGroupDocOrdinal = 0,		
		helpOptions = {
			@OptionCompleteSpec(
				name = "help",
				optionType = OptionType.GNU_SHORT_LONG,
				ordinal = 0
			),
			@OptionCompleteSpec(
				name = "h",
				optionType = OptionType.POSIX,
				ordinal = 1
			)
		},
		optionsDocUsage = "[options]",
		programHelpBody = "${programUsage}\n" 
			+ "Options:\n"
			+ "${optionsDoc.help}",
		programVersion = "Apache Ant" 
			+ " (${org.climax.demo.specTitle}"  
			+ " ${org.climax.demo.specVersion})",
		versionOptionGroupDocHelp =
			"  ${format:%-22s;p=usage}"
			+ " print the version information and exit",		
		versionOptionGroupDocOrdinal = 2,
		versionOptions = {
			@OptionCompleteSpec(
				optionType = OptionType.GNU_SHORT_LONG,
				name = "version"
			)
		}
	)
	private interface ant extends CLI {
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -autoproxy.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -autoproxy
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " Java1.5+: use the OS proxy settings",
			options = {
				@OptionCompleteSpec(
					name = "autoproxy",
					optionType = OptionType.GNU_SHORT_LONG
				)
			},
			ordinal = 22
		)
		OptionGroupComplete<Void> getAutoproxy();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options -buildfile, 
		 * -file, and -f.
		 * 
		 * @return the {@code OptionGroupComplete} for the options -buildfile, 
		 * -file, and -f
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=optionDoc0.usage}" 
				+ " use given buildfile\n"
				+ "    ${format:%-20s;p=optionDoc1.usage}"
				+ " ${format:%10s;v=''}\n"
				+ "    ${format:%-20s;p=optionDoc2.usage}"
				+ " ${format:%10s;v=''}",
			options = {
				@OptionCompleteSpec(
					name = "buildfile",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0,
					usage = "${option} <file>"
				),
				@OptionCompleteSpec(
					name = "file",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 1,
					usage = "${format:%-8s;p=option} <file>"
				),
				@OptionCompleteSpec(
					name = "f",
					optionType = OptionType.POSIX,
					ordinal = 2,
					usage = "${format:%-8s;p=option} <file>"
				)
			},
			ordinal = 13
		)
		OptionGroupComplete<File> getBuildfile();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -D.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -D
		 */
		@OptionGroupCompleteSpec(
			argParserClass = PropertyArgParser.class,
			argSeparator = ",",
			argsValidatorClass = SingleOrMultipleArgsValidator.class,
			help = "  ${format:%-22s;p=usage}"
				+ " use value for given property",
			options = {
				@OptionCompleteSpec(
					name = "D",
					optionType = OptionType.POSIX,
					usage = "${option}<property>=<value>"
				)
			},
			ordinal = 14
		)
		OptionGroupComplete<Map.Entry<String, String>> getD();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options -debug 
		 * and -d.
		 * 
		 * @return the {@code OptionGroupComplete} for the options -debug 
		 * and -d
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " print debugging information",				
			options = {
				@OptionCompleteSpec(
					name = "debug",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0
				),
				@OptionCompleteSpec(
					name = "d",
					optionType = OptionType.POSIX,
					ordinal = 1
				)
			},			
			ordinal = 6
		)		
		OptionGroupComplete<Void> getDebug();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -diagnostics. 
		 * 
		 * @return the {@code OptionGroupComplete} for the option -diagnostics
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}" 
				+ " print information that might be helpful to\n"
				+ "  ${format:%-22s;v= }"
				+ " diagnose or report problems",
			options = {
				@OptionCompleteSpec(
					name = "diagnostics",
					optionType = OptionType.GNU_SHORT_LONG
				)
			},
			ordinal = 3
		)		
		OptionGroupComplete<Void> getDiagnostics();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options -emacs 
		 * and -e.
		 * 
		 * @return the {@code OptionGroupComplete} for the options -emacs 
		 * and -e
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}" 
				+ " produce logging information without adornments",
			options = {
				@OptionCompleteSpec(
					name = "emacs",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0
				),
				@OptionCompleteSpec(
					name = "e",
					optionType = OptionType.POSIX,
					ordinal = 1
				)
			},				
			ordinal = 7
		)		
		OptionGroupComplete<Void> getEmacs();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options -find 
		 * and -s.
		 * 
		 * @return the {@code OptionGroupComplete} for the options -find 
		 * and -s
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=optionDoc0.usage}"
				+ " (s)earch for buildfile towards the root of\n"
				+ "    ${format:%-20s;p=optionDoc1.usage}"
				+ " the filesystem and use it",
			options = {
				@OptionCompleteSpec(
					name = "find",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0,
					usage = "${option} <file>"
				),
				@OptionCompleteSpec(
					name = "s",
					optionType = OptionType.POSIX,
					ordinal = 1,
					usage = "${format:%-3s;p=option} <file>"
				)
			},
			ordinal = 18
		)
		OptionGroupComplete<File> getFind();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option 
		 * -inputhandler.
		 * 
		 * @return the {@code OptionGroupComplete} for the option 
		 * -inputhandler
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " the class which will handle input requests",
			options = {
				@OptionCompleteSpec(
					name = "inputhandler",
					optionType = OptionType.GNU_SHORT_LONG,
					usage = "${option} <class>"
				)
			},
			ordinal = 17
		)
		OptionGroupComplete<Class<?>> getInputhandler();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options 
		 * -keep-going and -k.
		 * 
		 * @return the {@code OptionGroupComplete} for the options 
		 * -keep-going and -k
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " execute all targets that do not depend\n"
				+ "  ${format:%-22s;v= }"
				+ " on failed target(s)",
			options = {
				@OptionCompleteSpec(
					name = "keep-going",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0
				),
				@OptionCompleteSpec(
					name = "k",
					optionType = OptionType.POSIX,
					ordinal = 1
				)
			},
			ordinal = 15
		)
		OptionGroupComplete<Void> getKeepgoing();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -lib.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -lib
		 */
		@OptionGroupCompleteSpec(
			argSeparator = ArgSeparators.SYSTEM_ARG_SEPARATOR,
			argsValidatorClass = SingleOrMultipleArgsValidator.class,
			help = "  ${format:%-22s;p=usage}" 
				+ " specifies a path to search for jars and classes",
			options = {
				@OptionCompleteSpec(
					name = "lib",
					optionType = OptionType.GNU_SHORT_LONG,
					usage = "${option} <path>"
				)	
			},
			ordinal = 8
		)
		OptionGroupComplete<File> getLib();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -listener.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -listener
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " add an instance of class as a project listener",
			options = {
				@OptionCompleteSpec(
					name = "listener",
					optionType = OptionType.GNU_SHORT_LONG,
					usage = "${option} <classname>"
				)
			},
			ordinal = 11
		)
		OptionGroupComplete<Class<?>> getListener();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options -logfile 
		 * and -l.
		 * 
		 * @return the {@code OptionGroupComplete} for the options -logfile 
		 * and -l
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=optionDoc0.usage}"
				+ " use given file for log\n"
				+ "    ${format:%-20s;p=optionDoc1.usage}"
				+ " ${format:%10s;v=''}",
			options = {
				@OptionCompleteSpec(
					name = "logfile",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0,
					usage = "${option} <log>"
				),
				@OptionCompleteSpec(
					name = "l",
					optionType = OptionType.POSIX,
					ordinal = 1,
					usage = "${format:%-6s;p=option} <log>"
				)
			},
			ordinal = 9
		)
		OptionGroupComplete<File> getLogfile();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -logger.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -logger
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " the class which is to perform logging",
			options = {
				@OptionCompleteSpec(
					name = "logger",
					optionType = OptionType.GNU_SHORT_LONG,
					usage = "${option} <classname>"
				)
			},
			ordinal = 10
		)
		OptionGroupComplete<Class<?>> getLogger();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -main.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -main
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " override Ant's normal entry point",
			options = {
				@OptionCompleteSpec(
					name = "main",
					optionType = OptionType.GNU_SHORT_LONG,
					usage = "${option} <class>"
				)
			},
			ordinal = 23
		)
		OptionGroupComplete<Class<?>> getMain();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -nice.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -nice
		 */
		@OptionGroupCompleteSpec(
			argParserClass = NiceIntegerArgParser.class,
			defaultArguments = { "5" },
			help = "  ${format:%-22s;p=usage}"
				+ " A niceness value for the main thread:\n"
				+ "  ${format:%-22s;v= }"
				+ " 1 (lowest) to 10 (highest); 5 is the default",
			options = {
				@OptionCompleteSpec(
					name = "nice",
					optionType = OptionType.GNU_SHORT_LONG,
					usage = "${option}  number"
				)
			},
			ordinal = 19
		)
		OptionGroupComplete<Integer> getNice();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -noclasspath.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -noclasspath
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " Run ant without using CLASSPATH",
			options = {
				@OptionCompleteSpec(
					name = "noclasspath",
					optionType = OptionType.GNU_SHORT_LONG
				)	
			},
			ordinal = 21
		)
		OptionGroupComplete<Void> getNoClasspath();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -noinput.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -noinput
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " do not allow interactive input",
			options = {
				@OptionCompleteSpec(
					name = "noinput",
					optionType = OptionType.GNU_SHORT_LONG
				)	
			},
			ordinal = 12
		)
		OptionGroupComplete<Void> getNoInput();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option -nouserlib.
		 * 
		 * @return the {@code OptionGroupComplete} for the option -nouserlib
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " Run ant without using the jar files from\n"
				+ "  ${format:%-22s;v= }"
				+ " $${user.home}/.ant/lib",
			options = {
				@OptionCompleteSpec(
					name = "nouserlib",
					optionType = OptionType.GNU_SHORT_LONG
				)
			},
			ordinal = 20
		)
		OptionGroupComplete<Void> getNoUserLib();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options 
		 * -projecthelp and -p.
		 * 
		 * @return the {@code OptionGroupComplete} for the options 
		 * -projecthelp and -p
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}" 
				+ " print project help information",
			options = {
				@OptionCompleteSpec(
					name = "projecthelp",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0
				),
				@OptionCompleteSpec(
					name = "p",
					optionType = OptionType.POSIX,
					ordinal = 1
				)
			},
			ordinal = 1
		)
		OptionGroupComplete<Void> getProjecthelp();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the option 
		 * -propertyfile.
		 * 
		 * @return the {@code OptionGroupComplete} for the option 
		 * -propertyfile
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage}"
				+ " load all properties from file with -D\n"
				+ "  ${format:%-22s;v= }"
				+ " properties taking precedence",
			options = {
				@OptionCompleteSpec(
					name = "propertyfile",
					optionType = OptionType.GNU_SHORT_LONG,
					usage = "${option} <name>"
				)
			},
			ordinal = 16
		)
		OptionGroupComplete<File> getPropertyfile();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options -quiet 
		 * and -q.
		 * 
		 * @return the {@code OptionGroupComplete} for the options -quiet 
		 * and -q
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage} be extra quiet",				
			options = {
				@OptionCompleteSpec(
					name = "quiet",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0
				),
				@OptionCompleteSpec(
					name = "q",
					optionType = OptionType.POSIX,
					ordinal = 1
				)
			},				
			ordinal = 4
		)
		OptionGroupComplete<Void> getQuiet();
		
		/**
		 * Returns the {@code ArgGroupComplete} for the target argument group.
		 * 
		 * @return the {@code ArgGroupComplete} for the target argument group
		 */
		@ArgGroupCompleteSpec(
			argAcceptorClass = UnlimitedArgAcceptor.class,
			argsValidatorClass = PassiveArgsValidator.class,
			argumentType = "target",
			syntax = "${format:[%1$s [%1$s2 [%1$s3] ...]];p=argumentType}"
		)
		ArgGroupComplete<String> getTarget();
		
		/**
		 * Returns the {@code OptionGroupComplete} for the options -verbose 
		 * and -v.
		 * 
		 * @return the {@code OptionGroupComplete} for the options -verbose 
		 * and -v
		 */
		@OptionGroupCompleteSpec(
			help = "  ${format:%-22s;p=usage} be extra verbose",			
			options = {
				@OptionCompleteSpec(
					name = "verbose",
					optionType = OptionType.GNU_SHORT_LONG,
					ordinal = 0
				),
				@OptionCompleteSpec(
					name = "v",
					optionType = OptionType.POSIX,
					ordinal = 1
				)
			},				
			ordinal = 5
		)		
		OptionGroupComplete<Void> getVerbose();
	}
	
	
	/**
	 * A {@code ParameterlessArgParser} implementation that parses arguments 
	 * as {@code Integer}s for the option -nice.
	 */
	@Singleton
	private static final class NiceIntegerArgParser
		implements ParameterlessArgParser<Integer> {
		
		/** The {@code ArgParser}. */
		private final ArgParser<Integer> argParser;
		
		/**
		 * Constructs a {@code NiceIntegerArgParser}.
		 */
		@SuppressWarnings("unused")
		public NiceIntegerArgParser() {
			
			final int minNiceInteger = 1;
			final int maxNiceInteger = 10;
			
			this.argParser = new IntegerArgParser(
					Integer.valueOf(minNiceInteger), 
					Integer.valueOf(maxNiceInteger));
		}

		@Override
		public Integer parse(final String arg) throws ArgParserException {
			return this.argParser.parse(arg);
		}
	}

	/**
	 * A {@code ParameterlessArgParser} implementation that parses arguments 
	 * as instances of {@code Map.Entry} for the option -D.
	 */
	@Singleton	
	private static final class PropertyArgParser 
		implements ParameterlessArgParser<Map.Entry<String, String>> {

		/**
		 * Constructs a {@code PropertyArgParser}.
		 */
		@SuppressWarnings("unused")
		public PropertyArgParser() {
		}
		
		@Override
		public Map.Entry<String, String> parse(final String arg)
				throws ArgParserException {
			
			String[] splitArg = arg.split("=", 2);
			
			if (splitArg.length != 2) {
				
				String message = "argument must be of the following format: "
					+ "<property>=<value>";
				
				throw new ArgParserException(arg, message);				
			}
			
			String property = splitArg[0];
			String value = splitArg[1];
			
			return new AbstractMap.SimpleEntry<String, String>(
					property, value);
		}
		
	}

	/** A table for display as a {@code String}. */
	private static class Table {
		
		/**
		 * Appends the provided {@code String} multiple times based on the 
		 * provided integer indicating how many times to append.
		 *   
		 * @param string the provided {@code String}
		 * 
		 * @param times the provided integer indicating how many times to
		 * append
		 * 
		 * @return the appended String
		 */
		private static String append(final String string, final int times) {
			StringBuilder stringBuilder = new StringBuilder();
			for (int i = 0; i < times; i++) {
				stringBuilder.append(string);
			}
			return stringBuilder.toString();
		}
		
		/**
		 * Returns an {@code int} array of the maximum width of each column 
		 * based on the provided two-dimensional {@code Object} array of the 
		 * content.
		 * 
		 * @param cells the provided two-dimensional {@code Object} array of 
		 * the content
		 * 
		 * @return an {@code int} array of the maximum width of each column
		 */
		private static int[] getMaxColumnWidths(final Object[][] cells) {

			int maxColumnCount = 0;
			
			for (Object[] row : cells) {
				
				if (row.length > maxColumnCount) {
					maxColumnCount = row.length;
				}
			}
			
			int[] maxColumnWidths = new int[maxColumnCount];
			
			Arrays.fill(maxColumnWidths, 0);
			
			for (Object[] row : cells) {
				
				for (int i = 0; i < row.length; i++) {
					
					if (i < maxColumnWidths.length) {
						
						Object cell = row[i];
						
						int cellWidth = 0;
						
						if (cell != null) {
							
							cellWidth = cell.toString().length(); 
						}
						
						int maxColumnWidth = maxColumnWidths[i];
						
						if (cellWidth > maxColumnWidth) {
							
							maxColumnWidths[i] = cellWidth;
						}
					}
				}
			}
			
			return maxColumnWidths;
		}
		
		/**
		 * Creates a row based on the provided {@code Object} array of the 
		 * content and the provided {@code int} array of the maximum width of 
		 * each column.
		 * 
		 * @param row the provided {@code Object} array of the content
		 * 
		 * @param maxColumnWidths the provided {@code int} array of the maximum
		 * width of each column
		 * 
		 * @return a new row
		 */
		private static String newRow(
				final Object[] row, final int[] maxColumnWidths) {
			
			StringBuilder rowBuilder = new StringBuilder();
			
			rowBuilder.append('|');
			
			for (int i = 0; i < maxColumnWidths.length; i++) {
				
				int columnWidth = maxColumnWidths[i];
				
				if (i < row.length) {
					
					Object cell = row[i];
					
					if (cell != null) {
						
						rowBuilder.append(cell);
						
						int remainingSpaceLength = 
								columnWidth - cell.toString().length();
						
						if (remainingSpaceLength > 0) {
							
							rowBuilder.append(
									append(" ", remainingSpaceLength));
						}
						
					} else {
						
						rowBuilder.append(append(" ", columnWidth));
					}
					
				} else {
					
					rowBuilder.append(append(" ", columnWidth));
				}
				
				if (i < maxColumnWidths.length - 1) {
					
					rowBuilder.append('|');
				}
			}
			
			rowBuilder.append('|');
			
			return rowBuilder.toString();
		}
		
		/**
		 * Creates a new row separator based on the provided {@code int} array 
		 * of the maximum width of each column.
		 *  
		 * @param maxColumnWidths the provided {@code int} array of the maximum
		 * width of each column
		 * 
		 * @return a new row separator
		 */
		private static String newRowSeparator(final int[] maxColumnWidths) {
			
			StringBuilder rowSeparatorBuilder = new StringBuilder();
			
			rowSeparatorBuilder.append('+');
			
			for (int i = 0; i < maxColumnWidths.length; i++) {
				
				int maxColumnWidth = maxColumnWidths[i];
				
				rowSeparatorBuilder.append(append("-", maxColumnWidth));
				
				if (i < maxColumnWidths.length - 1) {
					
					rowSeparatorBuilder.append('+');
				}
			}
			
			rowSeparatorBuilder.append('+');
			
			return rowSeparatorBuilder.toString();
		}
		
		/** The {@code String} representation of this {@code Table}. */
		private final String string;
		
		/**
		 * Constructs a {@code Table} based on the provided 
		 * two-dimensional {@code Object} array of the content.
		 * 
		 * @param cells the provided two-dimensional {@code Object} array of 
		 * the content
		 */
		public Table(final Object[][] cells) {
			
			int[] maxColumnWidths = getMaxColumnWidths(cells);
			
			String rowSeparator = newRowSeparator(maxColumnWidths);
			
			StringBuilder tableBuilder = new StringBuilder();

			if (cells.length > 0) {
				
				tableBuilder.append(rowSeparator).append('\n');
				
				for (int i = 0; i < cells.length; i++) {
					
					Object[] row = cells[i];
										
					tableBuilder.append(
							newRow(row, maxColumnWidths)).append('\n');
					
					if (i < cells.length - 1) {
						
						tableBuilder.append(rowSeparator).append('\n');
					}
				}
				
				tableBuilder.append(rowSeparator);
			}
			
			this.string = tableBuilder.toString();
		}
		
		@Override
		public String toString() {
			return this.string;
		}
	}	
	
	/**
	 * Processes the supplied command line arguments and prints the results 
	 * to standard output.
	 * 
	 * @param args the supplied command line arguments
	 */
	public static void main(final String[] args) {
		
		CLIInterface<ant> c = CLIInterface.getInstance(ant.class);
		
		ant a = c.newCLI();
		
		switch(a.process(args, System.out, System.err)) {
		
		case ERROR:
			System.exit(1);
			
		case HELP_REQUESTED:
			return;
			
		case VERSION_REQUESTED:
			return;
			
		default:
			break;
		}
		
		Object[][] cells = new Object[][] {
				new Object[] {
					"OptionGroupComplete/ArgGroupComplete",
					"hasParsedOptionSelection/hasParsedArgument",
					"parsedArguments"
				},
				toTableRow(a.getAutoproxy()),
				toTableRow(a.getBuildfile()),
				toTableRow(a.getD()),
				toTableRow(a.getDebug()),
				toTableRow(a.getDiagnostics()),
				toTableRow(a.getEmacs()),
				toTableRow(a.getFind()),
				toTableRow(a.getInputhandler()),
				toTableRow(a.getKeepgoing()),
				toTableRow(a.getLib()),
				toTableRow(a.getListener()),
				toTableRow(a.getLogfile()),
				toTableRow(a.getLogger()),
				toTableRow(a.getMain()),
				toTableRow(a.getNice()),
				toTableRow(a.getNoClasspath()),
				toTableRow(a.getNoInput()),
				toTableRow(a.getNoUserLib()),
				toTableRow(a.getProjecthelp()),
				toTableRow(a.getPropertyfile()),
				toTableRow(a.getQuiet()),
				toTableRow(a.getVerbose()),
				new Object[] {
					a.getTarget().getArgumentType() + "(s)",
					a.getTarget().hasArgument(),
					a.getTarget().getParsedArguments()
				}
		};
		
		System.out.println(new Table(cells));
	}
	
	/**
	 * Returns a {@code String} representation of a provided {@code List} of 
	 * {@code Option}s.
	 * 
	 * @param optionList the provided {@code List} of {@code Option}s.
	 * 
	 * @return a {@code String} representation of a provided {@code List} of 
	 * {@code Option}s
	 */
	private static String toString(final List<Option> optionList) {
		StringBuilder builder = new StringBuilder();
		for (Iterator<Option> it = optionList.iterator(); it.hasNext();) {
			Option option = it.next();
			builder.append(option.toOptionString());
			if (it.hasNext()) {
				builder.append(", ");
			}
		}
		return builder.toString();
	}
	
	/**
	 * Returns a {@code Object} array as a table row of the provided 
	 * {@code OptionGroupComplete}.
	 * 
	 * @param optionGroupComplete the provided {@code OptionGroupComplete}
	 * 
	 * @return the arguments
	 */
	private static Object[] toTableRow(
			final OptionGroupComplete<?> optionGroupComplete) {
		
		return new Object[] { 
				toString(optionGroupComplete.getOptions()),
				optionGroupComplete.hasParsedOptionSelection(),
				optionGroupComplete.getParsedArguments()
		};
	}
	
	/**
	 * Constructs an instance of {@code Ant}. This constructor is 
	 * suppressed for noninstantiability outside this class.
	 */
	private Ant() {
	}
}
