/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Map;

/**
 * An implementation of {@code AbstractFactory}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class AbstractFactoryImpl extends AbstractFactory {

	/**
	 * Constructs an {@code AbstractFactoryImpl}.
	 */
	AbstractFactoryImpl() {
	}

	@Override
	public Comparator<ArgGroup<?>> getArgGroupComparator() {
		return ArgGroupComparatorImpl.getInstance();
	}

	@Override
	public Comparator<ArgGroupDoc> getArgGroupDocComparator() {
		return ArgGroupDocComparatorImpl.getInstance();
	}

	@Override
	public Comparator<Option> getOptionByNameComparator() {
		return OptionByNameComparatorImpl.getInstance();
	}

	@Override
	public Comparator<Option> getOptionComparator() {
		return OptionComparatorImpl.getInstance();
	}

	@Override
	public Comparator<OptionDoc> getOptionDocByOptionNameComparator() {
		return OptionDocByOptionNameComparatorImpl.getInstance();
	}

	@Override
	public Comparator<OptionDoc> getOptionDocComparator() {
		return OptionDocComparatorImpl.getInstance();
	}

	@Override
	public Comparator<OptionGroupDoc> getOptionGroupDocComparator() {
		return OptionGroupDocComparatorImpl.getInstance();
	}

	@Override
	public Comparator<Package> getPackageComparator() {
		return PackageComparatorImpl.getInstance();
	}

	@Override
	public PackageDoc getPackageDoc(final Package pkg) {
		return PackageDocImpl.of(pkg);
	}

	@Override
	public Comparator<PackageDoc> getPackageDocComparator() {
		return PackageDocComparatorImpl.getInstance();
	}

	@Override
	public List<PackageDoc> getPackageDocs() {
		List<PackageDoc> packageDocList = new ArrayList<PackageDoc>(
				PackageDocImpl.getPackageDocImpls());
		return Collections.unmodifiableList(packageDocList);
	}

	@Override
	public Map<String, String> getPackageDocsProperties() {
		return PackageDocImpl.getPackageDocImplsProperties();
	}

	@Override
	public List<Package> getPackages() {
		return PackageDocImpl.getPackages();
	}

	@Override
	public SystemDoc getSystemDoc() {
		return SystemDocImpl.getInstance();
	}

	@Override
	public Map<String, String> getSystemDocProperties() {
		return SystemDocImpl.getSystemDocImplProperties();
	}

	@Override
	public <T> ArgGroupBuilder<T> newArgGroupBuilder(
			final String argumentType,
			final ArgParser<? extends T> argParser) {
		
		return new ArgGroupImpl.Builder<T>(argumentType, argParser);
	}

	@Override
	public <T> ArgGroupCompleteBuilder<T> newArgGroupCompleteBuilder(
			final String argumentType, 
			final ArgParser<? extends T> argParser) {
		
		return new ArgGroupCompleteImpl.Builder<T>(argumentType, argParser);
	}

	@Override
	public ArgGroupDocBuilder newArgGroupDocBuilder(
			final ArgGroup<? extends Object> argGroup) {
		
		return new ArgGroupDocImpl.Builder(argGroup);
	}

	@Override
	public Args newArgs() {
		return new ArgsImpl();
	}

	@Override
	public Args newArgs(final Args args) {
		return new ArgsImpl(args);
	}

	@Override
	public ArgsComplete newArgsComplete() {
		return new ArgsCompleteImpl();
	}

	@Override
	public ArgsComplete newArgsComplete(
			final ArgsComplete argsComplete) {
		
		return new ArgsCompleteImpl(argsComplete);
	}

	@Override
	public ArgsDoc newArgsDoc() {
		return new ArgsDocImpl();
	}

	@Override
	public ArgsDoc newArgsDoc(final ArgsDoc argsDoc) {
		return new ArgsDocImpl(argsDoc);
	}

	@Override
	public CLIBuilder newCLIBuilder(final String programName) {
		return new CLIImpl.Builder(programName);
	}

	@Override
	public Option newOption(final OptionType optionType, final String name) {
		return new OptionImpl(optionType, name);
	}

	@Override
	public OptionCompleteBuilder newOptionCompleteBuilder(
			final OptionType optionType, final String name) {
		
		return new OptionCompleteImpl.Builder(optionType, name);
	}

	@Override
	public OptionDocBuilder newOptionDocBuilder(final Option option) {
		return new OptionDocImpl.Builder(option);
	}

	@Override
	public <T> OptionGroupBuilder<T> newOptionGroupBuilder(
			final List<Option> optionList) {
		
		return new OptionGroupImpl.Builder<T>(optionList);
	}

	@Override
	public <T> OptionGroupCompleteBuilder<T> newOptionGroupCompleteBuilder(
			final List<OptionComplete> optionCompleteList) {
		
		return new OptionGroupCompleteImpl.Builder<T>(optionCompleteList);
	}

	@Override
	public OptionGroupDocBuilder newOptionGroupDocBuilder(
			final List<OptionDoc> optionDocList) {
		
		return new OptionGroupDocImpl.Builder(optionDocList);
	}

	@Override
	public Options newOptions() {
		return new OptionsImpl();
	}

	@Override
	public Options newOptions(final Options options) {
		return new OptionsImpl(options);
	}

	@Override
	public OptionsComplete newOptionsComplete() {
		return new OptionsCompleteImpl();
	}

	@Override
	public OptionsComplete newOptionsComplete(
			final OptionsComplete optionsComplete) {
		
		return new OptionsCompleteImpl(optionsComplete);
	}

	@Override
	public OptionsDoc newOptionsDoc() {
		return new OptionsDocImpl();
	}

	@Override
	public OptionsDoc newOptionsDoc(final OptionsDoc optionsDoc) {
		return new OptionsDocImpl(optionsDoc);
	}

	@Override
	public <T> OptionSelection<T> newOptionSelection(
			final Option option, final T argument) {
		
		return new OptionSelectionImpl<T>(option, argument);
	}

	@Override
	public void setPackages(final List<Package> pkgList) {
		PackageDocImpl.setPackages(pkgList);
	}
}
