/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;


/**
 * A group of arguments of the specified parsed argument type.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 * @param <T> the specified parsed argument type
 */
public interface ArgGroup<T> {

	/**
	 * Adds an argument to this {@code ArgGroup}. 
	 * 
	 * @param argument the specified argument
	 */
	void addArgument(final String argument);
	
	/**
	 * Removes all arguments with the exception of the default argument(s).
	 */
	void clearArguments();
	
	/**
	 * Removes all arguments of the specified parsed argument type with the 
	 * exception of the default argument(s) of the specified parsed argument 
	 * type.
	 */
	void clearParsedArguments();

	/**
	 * Returns the {@code ArgAcceptor}.
	 * 
	 * @return the {@code ArgAcceptor}
	 */
	ArgAcceptor getArgAcceptor();
	
	/**
	 * Returns the {@code ArgParser}.
	 * 
	 * @return the {@code ArgParser}
	 */
	ArgParser<T> getArgParser(); 
	
	/**
	 * Returns the {@code ArgsValidator}.
	 * 
	 * @return the {@code ArgsValidator}
	 */
	ArgsValidator getArgsValidator();
	
	/**
	 * Returns an unmodifiable {@code List} of the arguments.
	 * 
	 * @return an unmodifiable {@code List} of the arguments
	 */
	List<String> getArguments();
	
	/**
	 * Returns the argument type.
	 * 
	 * @return the argument type
	 */
	String getArgumentType();
	
	/**
	 * Returns the ordinal of this {@code ArgGroup} in relation to other
	 * {@code ArgGroup}s.
	 * 
	 * @return the ordinal of this {@code ArgGroup} in relation to other
	 * {@code ArgGroup}s
	 */
	int getOrdinal();
	
	/**
	 * Returns an unmodifiable {@code List} of arguments of the specified 
	 * parsed argument type.
	 * 
	 * @return an unmodifiable {@code List} of arguments of the specified 
	 * parsed argument type
	 */	
	List<T> getParsedArguments();
	
	/**
	 * Indicates that this {@code ArgGroup} has at least one argument.
	 * 
	 * @return {@code true} if this {@code ArgGroup} has at least one 
	 * argument
	 */
	boolean hasArgument();

	/**
	 * Indicates that this {@code ArgGroup} has at least one argument of the 
	 * specified parsed argument type.
	 *  
	 * @return {@code true} if this {@code ArgGroup} has at least one 
	 * argument of the specified parsed argument type
	 */
	boolean hasParsedArgument();
	
	/**
	 * Parses the arguments to arguments of the specified parsed argument 
	 * type.
	 * 
	 * @throws ArgGroupException if the arguments are invalid or cannot be 
	 * parsed.
	 */
	void parse() throws ArgGroupException;
}
