/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * A builder for an {@code ArgGroup} of the specified parsed argument 
 * type.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 * @param <T> the specified parsed argument type
 */
public interface ArgGroupBuilder<T> {
	
	/**
	 * Sets the {@code ArgAcceptor}.
	 * 
	 * @param a the provided {@code ArgAcceptor}
	 * 
	 * @return this builder
	 */
	ArgGroupBuilder<T> argAcceptor(final ArgAcceptor a);
	
	/**
	 * Sets the {@code ArgsValidator}.
	 * 
	 * @param v the provided {@code ArgsValidator}
	 * 
	 * @return this builder
	 */	
	ArgGroupBuilder<T> argsValidator(final ArgsValidator v);
	
	/**
	 * Builds a new {@code ArgGroup} of the specified parsed 
	 * argument type.
	 *  
	 * @return a new {@code ArgGroup} of the specified parsed 
	 * argument type
	 */
	ArgGroup<T> buildArgGroup();
	
	/**
	 * Sets the default argument format strings with the provided {@code List} 
	 * of default argument format strings.
	 * <p>
	 * The following are property keys that can be applied as expandable 
	 * properties within the provided format strings:
	 * </p>
	 * <ul>
	 * <li>Property keys defined in {@link System#getProperties()}</li>
	 * </ul>
	 * 
	 * @param l the provided {@code List} of default argument format strings
	 * 
	 * @return this builder
	 */	
	ArgGroupBuilder<T> defaultArguments(final List<String> l);
	
	/**
	 * Sets the ordinal of the {@code ArgGroup} in relation to other 
	 * {@code ArgGroup}s.
	 * 
	 * @param i the provided ordinal of the {@code ArgGroup} in relation to 
	 * other {@code ArgGroup}s
	 * 
	 * @return this builder
	 */	
	ArgGroupBuilder<T> ordinal(final int i);
}