/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code ArgGroup}s first by their 
 * ordinals and then by their argument types.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class ArgGroupComparatorImpl implements Comparator<ArgGroup<?>> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgGroupComparatorHolder.ARGGROUP_COMPARATOR}.
	 */
	private static final class ArgGroupComparatorHolder {
		
		/** The {@code ArgGroupComparatorImpl}. */
		static final ArgGroupComparatorImpl ARGGROUP_COMPARATOR = 
				new ArgGroupComparatorImpl();
		
		/**
		 * Constructs an {@code ArgGroupComparatorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */	
		private ArgGroupComparatorHolder() {
		}
	}
	
	/**
	 * Returns an {@code ArgGroupComparatorImpl}.
	 * 
	 * @return an {@code ArgGroupComparatorImpl}
	 */
	static ArgGroupComparatorImpl getInstance() {
		return ArgGroupComparatorHolder.ARGGROUP_COMPARATOR;
	}
	
	/**
	 * Constructs an {@code ArgGroupComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private ArgGroupComparatorImpl() {
	}
	
	@Override
	public int compare(final ArgGroup<?> o1, final ArgGroup<?> o2) {
		
		int result = o1.getOrdinal() - o2.getOrdinal();
		
		if (result != 0) { return result; }
		
		return o1.getArgumentType().compareTo(o2.getArgumentType());
	}

}
