/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * A builder for an {@code ArgGroupComplete} of the specified parsed 
 * argument type.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 * @param <T> the specified parsed argument type
 */
public interface ArgGroupCompleteBuilder<T> 
	extends ArgGroupBuilder<T>, ArgGroupDocBuilder {
	
	@Override
	ArgGroupCompleteBuilder<T> argAcceptor(final ArgAcceptor a);
	
	@Override	
	ArgGroupCompleteBuilder<T> argsValidator(final ArgsValidator v);
	
	/**
	 * Builds a new {@code ArgGroupComplete} of the specified parsed 
	 * argument type.
	 * 
	 * @return a new {@code ArgGroupComplete} of the specified parsed 
	 * argument type
	 */
	ArgGroupComplete<T> buildArgGroupComplete();
	
	@Override	
	ArgGroupCompleteBuilder<T> defaultArguments(final List<String> l);	
	
	/**
	 * Sets the boolean value to indicate if the {@code ArgGroupComplete} 
	 * is excluded from documentation.
	 * 
	 * @param b the provided boolean value to indicate if the 
	 * {@code ArgGroupComplete} is excluded from documentation
	 * 
	 * @return this builder
	 */
	ArgGroupCompleteBuilder<T> hidden(final boolean b);
	
	@Override
	ArgGroupCompleteBuilder<T> ordinal(final int i);
	
	@Override	
	ArgGroupCompleteBuilder<T> syntax(final String s);
	
	/**
	 * Sets the boolean value to indicate if the {@code ArgGroupComplete} 
	 * is excluded from parsing.
	 * 
	 * @param b the provided boolean value to indicate if the 
	 * {@code ArgGroupComplete} is excluded from parsing
	 * 
	 * @return this builder
	 */
	ArgGroupCompleteBuilder<T> unused(final boolean b);
}
