/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

/**
 * A builder for an {@code ArgGroupDoc}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public interface ArgGroupDocBuilder {
	
	/**
	 * Builds a new {@code ArgGroupDoc}.
	 * 
	 * @return a new {@code ArgGroupDoc}
	 */
	ArgGroupDoc buildArgGroupDoc();
	
	/**
	 * Sets the format string for the syntax for the {@code ArgGroup}.
	 * <p>
	 * The following are property keys that can be applied as expandable 
	 * properties within the provided format string:
	 * </p>
	 * <table border="1"><tr><th>Property Key(s)</th></tr>
	 * <tr><td>Property keys defined in {@link System#getProperties()}</td></tr>
	 * <tr><td>Property keys prefixed with the name of a package followed by a 
	 * dot (.) and the package's property key defined in 
	 * {@link org.climax.PackageDocPropertyKeys}.</td></tr>
	 * <tr><td>{@link org.climax.ArgGroupDocPropertyKeys#ARGUMENT_TYPE}
	 * ({@value org.climax.ArgGroupDocPropertyKeys#ARGUMENT_TYPE})</td></tr> 
	 * </table>
	 * 
	 * @param s the provided format string for the usage for the
	 * {@code ArgGroup}
	 * 
	 * @return this builder
	 * 
	 * @see <a href="package-summary.html#3">Expandable Properties</a>
	 */	
	ArgGroupDocBuilder syntax(final String s);
}