/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code ArgGroupDoc}s by their 
 * {@code ArgGroup}s.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class ArgGroupDocComparatorImpl implements Comparator<ArgGroupDoc> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgGroupDocComparatorHolder.ARGGROUPDOC_COMPARATOR}.
	 */
	private static final class ArgGroupDocComparatorHolder {
		
		/** The {@code ArgGroupDocComparatorImpl}. */
		static final ArgGroupDocComparatorImpl ARGGROUPDOC_COMPARATOR = 
				new ArgGroupDocComparatorImpl();
		
		/**
		 * Constructs an {@code ArgGroupDocComparatorHolder}. This constructor 
		 * is suppressed for noninstantiability outside of this class.
		 */
		private ArgGroupDocComparatorHolder() {
		}
	}
	
	/**
	 * Returns an {@code ArgGroupDocComparatorImpl}.
	 * 
	 * @return an {@code ArgGroupDocComparatorImpl}
	 */
	static ArgGroupDocComparatorImpl getInstance() {
		return ArgGroupDocComparatorHolder.ARGGROUPDOC_COMPARATOR;
	}
	
	/**
	 * Constructs an {@code ArgGroupDocComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private ArgGroupDocComparatorImpl() {
	}
	
	@Override
	public int compare(final ArgGroupDoc o1, final ArgGroupDoc o2) {
		return AbstractFactory.getDefault().getArgGroupComparator().compare(
				o1.getArgGroup(), o2.getArgGroup());
	}

}
