/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

/**
 * Thrown when an {@code ArgParser} cannot parse an argument.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class ArgParserException extends Exception {

	/** The default serial version UID. */
	private static final long serialVersionUID = 1L;

	/** The nonparsable argument. */
	private final String argument;
	
	/**
	 * Constructs an {@code ArgParserException} with the nonparsable argument
	 * and the specified detail message.
	 * 
	 * @param arg the nonparsable argument
	 * @param message the detail message
	 */
	public ArgParserException(final String arg, final String message) {
		
		this(arg, message, null);
	}

	/**
	 * Constructs an {@code ArgParserException} with the nonparsable argument,
	 * the specified detail message, and the optional {@code Throwable} that 
	 * was raised while trying to parse the argument.
	 * 
	 * @param arg the nonparsable argument
	 * 
	 * @param message the detail message
	 * 
	 * @param cause the {@code Throwable} that was raised while trying to parse
	 * the argument 
	 */
	public ArgParserException(
			final String arg, final String message, final Throwable cause) {
		
		super(message, cause);
		
		this.argument = arg;
	}

	/**
	 * Returns the nonparsable argument.
	 * 
	 * @return the nonparsable argument
	 */
	public String getArgument() {
		return this.argument;
	}
}
