/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

/**
 * This class contains defined argument separator strings.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class ArgSeparators {

	/**
	 * The non argument separator string. 
	 * <p>
	 * This field is initialized with the string of a regular expression of a 
	 * negation character class of word characters and non-word characters. 
	 * This string is used to not separate any arguments.
	 * </p>
	 */
	public static final String NON_ARG_SEPARATOR = "[^\\w\\W]";

	/**
	 * The system-dependent argument separator string.
	 * <p> 
	 * This field is initialized with the string of an expandable property of 
	 * the system property {@code path.separator}. When expanded, this string 
	 * is used to separate arguments in a sequence of arguments given as an 
	 * <i>arguments list</i>. On UNIX systems, the string is expanded to ":"; 
	 * on Microsoft Windows systems it is expanded to ";".
	 * </p> 
	 */
	public static final String SYSTEM_ARG_SEPARATOR = "${path.separator}";

	/**
	 * Constructs an instance of {@code ArgSeparators}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private ArgSeparators() {
	}
}
