/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * A group of {@code ArgGroup}s. 
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public interface Args {
	
	/**
	 * Adds an {@code ArgGroup} to this {@code Args}.
	 * 
	 * @param argGroup the provided {@code ArgGroup}
	 */
	void addArgGroup(final ArgGroup<? extends Object> argGroup);
	
	/**
	 * Returns a sorted unmodifiable {@code List} of {@code ArgGroup}s.
	 * 
	 * @return a sorted unmodifiable {@code List} of {@code ArgGroup}s
	 */
	List<ArgGroup<Object>> getArgGroups();
	
	/**
	 * Parses the command line arguments. 
	 * <p>
	 * Before parsing the command line arguments, each {@code ArgGroup} 
	 * in the sorted {@code List} of {@code ArgGroup}s receives its turn 
	 * in accepting remaining command line arguments based on its 
	 * {@code ArgAcceptor}. Once all of the {@code ArgGroup}s have had 
	 * their turn in accepting the remaining command line arguments, 
	 * each {@code ArgGroup} parses their accepted arguments.
	 * </p>
	 * 
	 * @param args the command line arguments
	 * 
	 * @throws ArgsException if the command line arguments are invalid or 
	 * cannot be parsed or if one or more of the command line arguments 
	 * must be required
	 */
	void parse(final String[] args) throws ArgsException;
}
