/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * An implementation of an {@code ArgsComplete}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class ArgsCompleteImpl implements ArgsComplete {

	/** The {@code List} of {@code ArgGroupComplete}s. */
	private final List<ArgGroupComplete<Object>> argGroupCompleteList;
	
	/** The {@code ArgsDoc}. */
	private final ArgsDoc argsInstanceDoc;
	
	/** The {@code Args}. */
	private final Args argsInstance;
	
	/**
	 * Constructs an {@code ArgsCompleteImpl}.
	 */
	ArgsCompleteImpl() {
		
		this.argGroupCompleteList = new ArrayList<ArgGroupComplete<Object>>();
		this.argsInstanceDoc = AbstractFactory.getDefault().newArgsDoc();
		this.argsInstance = AbstractFactory.getDefault().newArgs();
	}
	
	/**
	 * Constructs an {@code ArgsCompleteImpl} with the provided 
	 * {@code ArgsComplete}.
	 * 
	 * @param argsComplete the provided {@code ArgsComplete}
	 */
	ArgsCompleteImpl(final ArgsComplete argsComplete) {
		
		this.argGroupCompleteList = new ArrayList<ArgGroupComplete<Object>>(
				argsComplete.getArgGroupCompletes());
		this.argsInstanceDoc = AbstractFactory.getDefault().newArgsDoc(
				argsComplete);
		this.argsInstance = AbstractFactory.getDefault().newArgs(
				argsComplete);
	}
	
	@Override
	public void addArgGroup(final ArgGroup<? extends Object> argGroup) {
		this.argsInstance.addArgGroup(argGroup);
	}
	
	@Override
	public void addArgGroupComplete(
			final ArgGroupComplete<? extends Object> argGroupComplete) {
		
		if (argGroupComplete == null) {
			throw new NullPointerException(
					"argGroupComplete must not be null");
		}
		
		if (!argGroupComplete.isHidden()) {
			this.argsInstanceDoc.addArgGroupDoc(argGroupComplete);
		}
		
		if (!argGroupComplete.isUnused()) {
			this.argsInstance.addArgGroup(argGroupComplete);
		}
		
		@SuppressWarnings("unchecked")
		ArgGroupComplete<Object> arGroupComplete =
			(ArgGroupComplete<Object>) argGroupComplete;
		
		this.argGroupCompleteList.add(arGroupComplete);
	}

	@Override
	public void addArgGroupDoc(final ArgGroupDoc argGroupDoc) {
		this.argsInstanceDoc.addArgGroupDoc(argGroupDoc);
	}
	
	@Override
	public List<ArgGroupComplete<Object>> getArgGroupCompletes() {
		return Collections.unmodifiableList(this.argGroupCompleteList);
	}

	@Override
	public List<ArgGroupDoc> getArgGroupDocs() {
		return this.argsInstanceDoc.getArgGroupDocs();
	}

	@Override
	public List<ArgGroup<Object>> getArgGroups() {
		return this.argsInstance.getArgGroups();
	}

	@Override
	public Map<String, String> getProperties() {
		return this.argsInstanceDoc.getProperties();
	}

	@Override
	public String getSyntax() {
		return this.argsInstanceDoc.getSyntax();
	}

	@Override
	public void parse(final String[] args) throws ArgsException {
		this.argsInstance.parse(args);
	}

	@Override
	public void setSyntax(final String s) {
		this.argsInstanceDoc.setSyntax(s);
	}

	@Override
	public String toString() {
		return String.format("ArgsComplete [" 
				+ "argGroupCompletes=%s, " 
				+ "argsDoc=%s, " 
				+ "args=%s]",
				this.argGroupCompleteList, 
				this.argsInstanceDoc, 
				this.argsInstance);
	}	
}
