/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * The documentation for the {@code Args}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public interface ArgsDoc extends Doc {

	/**
	 * Adds an {@code ArgGroupDoc} to this {@code ArgsDoc}.
	 * 
	 * @param argGroupDoc the provided {@code ArgGroupDoc}
	 */
	void addArgGroupDoc(final ArgGroupDoc argGroupDoc);

	/**
	 * Returns a sorted unmodifiable {@code List} of {@code ArgGroupDoc}s.
	 * 
	 * @return a sorted unmodifiable {@code List} of {@code ArgGroupDoc}s
	 */
	List<ArgGroupDoc> getArgGroupDocs();
	
	/**
	 * Returns the syntax for the {@code Args}.
	 * 
	 * @return the syntax for the {@code Args}
	 */
	String getSyntax();

	/**
	 * Sets the format string for the syntax for the {@code Args}.
	 * <p>
	 * The following are property keys that can be applied as expandable 
	 * properties within the provided format string:
	 * </p>
	 * <table border="1"><tr><th>Property Key(s)</th></tr>
	 * <tr><td>Property keys defined in {@link System#getProperties()}</td></tr>
	 * <tr><td>Property keys prefixed with the name of a package followed by a 
	 * dot (.) and the {@code PackageDoc}'s property key defined in 
	 * {@link org.climax.PackageDocPropertyKeys}.</td></tr>
	 * <tr><td>Property keys prefixed with
	 * {@link org.climax.ArgsDocPropertyKeys#ARGGROUPDOC_PREFIX}
	 * ({@value org.climax.ArgsDocPropertyKeys#ARGGROUPDOC_PREFIX}) followed 
	 * by an integer representing the index of an {@code ArgGroupDoc} (whose 
	 * range is from {@code 0} to <i>n</i> where {@code 0} is the first 
	 * {@code ArgGroupDoc} and <i>n</i> is the last {@code ArgGroupDoc}), a 
	 * dot (.), and the {@code ArgGroupDoc}'s property key defined in 
	 * {@link org.climax.ArgGroupDocPropertyKeys}.</td></tr>
	 * </table>
	 * 
	 * @param s the provided format string for the syntax for the 
	 * {@code Args}
	 * 
	 * @see <a href="package-summary.html#3">Expandable Properties</a> 
	 */	
	void setSyntax(final String s);
}
