/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Thrown when an {@code ArgsValidator} finds the arguments invalid.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class ArgsValidatorException extends Exception {
	
	/** The default serial version UID. */
	private static final long serialVersionUID = 1L;
	
	/** The {@code List} of the invalid arguments. */
	private final List<String> argumentList;
	
	/**
	 * Constructs an {@code ArgsValidatorException} with the provided 
	 * {@code List} of the invalid arguments and the specified detail 
	 * message.
	 * 
	 * @param argList the provided {@code List} of the invalid arguments
	 * @param message the detail message
	 */
	public ArgsValidatorException(
			final List<String> argList, final String message) {
		
		this(argList, message, null);
	}
	
	/**
	 * Constructs an {@code ArgsValidatorException} with the provided 
	 * {@code List} of the invalid arguments, the specified detail message, and
	 * the optional {@code Throwable} that was raised from finding the 
	 * arguments invalid.
	 * 
	 * @param argList the provided {@code List} of the invalid arguments
	 * 
	 * @param message the detail message
	 * 
	 * @param cause the {@code Throwable} that was raised from finding the 
	 * arguments invalid
	 */
	public ArgsValidatorException(
			final List<String> argList, 
			final String message, 
			final Throwable cause) {
		
		super(message, cause);
		
		this.argumentList = new ArrayList<String>(argList);
	}

	/**
	 * Returns an unmodifiable {@code List} of the invalid arguments.
	 * 
	 * @return an unmodifiable {@code List} of the invalid arguments
	 */
	public List<String> getArguments() {
		
		return Collections.unmodifiableList(this.argumentList);
	}
}
