/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Thrown when the default arguments are invalid or cannot be parsed.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class DefaultArgsException extends RuntimeException {

	/** The default serial version UID. */
	private static final long serialVersionUID = 1L;

	/** The {@code List} of arguments that are invalid or cannot be parsed. */
	private final List<String> defaultArgumentList;
	
	/**
	 * Constructs a {@code DefaultArgsException} with the provided {@code List} 
	 * of default arguments that are invalid or cannot be parsed and the 
	 * specified detail message.
	 * 
	 * @param defaultArgList the provided {@code List} of default arguments that
	 * are invalid or cannot be parsed
	 * 
	 * @param message the detail message
	 */
	public DefaultArgsException(
			final List<String> defaultArgList,
			final String message) {
		
		this(defaultArgList, message, null);
	}
	
	/**
	 * Constructs a {@code DefaultArgsException} with the provided {@code List} 
	 * of default arguments that are invalid or cannot be parsed, the specified 
	 * detail message, and the optional {@code Throwable} that was raised.
	 * 
	 * @param defaultArgList the provided {@code List} of default arguments that
	 * are invalid or cannot be parsed
	 * 
	 * @param message the detail message
	 * 
	 * @param cause the {@code Throwable} that was raised
	 */
	public DefaultArgsException(
			final List<String> defaultArgList,
			final String message,
			final Throwable cause) {
		
		super(message, cause);
		
		this.defaultArgumentList = new ArrayList<String>();
		
		this.defaultArgumentList.addAll(defaultArgList);
	}
	
	/**
	 * Returns an unmodifiable {@code List} of default arguments that are 
	 * invalid or cannot be parsed.
	 * 
	 * @return an unmodifiable {@code List} of default arguments that are 
	 * invalid or cannot be parsed
	 */	
	public List<String> getDefaultArguments() {
		return Collections.unmodifiableList(this.defaultArgumentList);
	}
}
