/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Iterator;
import java.util.List;

/**
 * This class provides utility methods regarding {@code List}s.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class Lists {

	/**
	 * Returns a {@code String} representation of the provided {@code List}. 
	 * The {@code String} representation consists of a list of the provided 
	 * {@code List}'s elements. Each element is enclosed by a grave accent (`) 
	 * and a single quote ('). Adjacent elements are separated by the 
	 * characters ", " (comma and space). Elements are converted to strings as 
	 * by {@link String#valueOf(Object)}.
	 * 
	 * @param list the provided {@code List}
	 * @return the {@code String} representation of the provided {@code List}
	 */
	static String toString(final List<?> list) {
		
		StringBuilder builder = new StringBuilder();
		
		for (Iterator<?> it = list.iterator(); it.hasNext();) {
			
			Object object = it.next();
			
			String objectString = String.valueOf(object);
			
			builder.append(String.format("`%s'", objectString));
			
			if (it.hasNext()) {
				
				builder.append(", ");
			}			
		}

		return builder.toString();
	}
	
	/**
	 * Constructs an instance of {@code Lists}. This constructor is suppressed 
	 * for noninstantiability outside of this class.
	 */
	private Lists() {
	}
}
