/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code Option}s by their names.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class OptionByNameComparatorImpl implements Comparator<Option> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code OptionComparatorHolder.OPTION_COMPARATOR}.
	 */
	private static final class OptionComparatorHolder {
		
		/** The {@code OptionByNameComparatorImpl}. */
		static final OptionByNameComparatorImpl OPTION_COMPARATOR =
				new OptionByNameComparatorImpl();
		
		/**
		 * Constructs an {@code OptionComparatorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */	
		private OptionComparatorHolder() {
		}
	}
	
	/**
	 * Returns an {@code OptionByNameComparatorImpl}.
	 * 
	 * @return an {@code OptionByNameComparatorImpl}
	 */
	static OptionByNameComparatorImpl getInstance() {
		return OptionComparatorHolder.OPTION_COMPARATOR;
	}
	
	/**
	 * Constructs an {@code OptionByNameComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private OptionByNameComparatorImpl() {
	}

	@Override
	public int compare(final Option o1, final Option o2) {
		return o1.getName().compareTo(o2.getName());
	}

}
