/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code Option}s first by 
 * their {@code OptionType}s and then by their names.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class OptionComparatorImpl implements Comparator<Option> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code OptionComparatorHolder.OPTION_COMPARATOR}.
	 */
	private static final class OptionComparatorHolder {
		
		/** The {@code OptionComparatorImpl}. */
		static final OptionComparatorImpl OPTION_COMPARATOR =
				new OptionComparatorImpl();
		
		/**
		 * Constructs an {@code OptionComparatorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */	
		private OptionComparatorHolder() {
		}
	}
	
	/**
	 * Returns an {@code OptionComparatorImpl}.
	 * 
	 * @return an {@code OptionComparatorImpl}
	 */
	static OptionComparatorImpl getInstance() {
		return OptionComparatorHolder.OPTION_COMPARATOR;
	}
	
	/**
	 * Constructs an {@code OptionComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private OptionComparatorImpl() {
	}

	@Override
	public int compare(final Option o1, final Option o2) {
		int result = o1.getOptionType().compareTo(o2.getOptionType());
		if (result != 0) { return result; }
		Comparator<Option> comparator = 
				AbstractFactory.getDefault().getOptionByNameComparator();
		return comparator.compare(o1, o2);
	}

}
