/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

/**
 * A builder for an {@code OptionDoc}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public interface OptionDocBuilder {
	
	/**
	 * Builds a new {@code OptionDoc}.
	 * 
	 * @return a new {@code OptionDoc}
	 */
	OptionDoc buildOptionDoc();
	
	/**
	 * Sets the ordinal of the {@code OptionDoc} in relation to 
	 * other {@code OptionDoc}s.
	 * 
	 * @param i the provided ordinal of the {@code OptionDoc} in 
	 * relation to other {@code OptionDoc}s
	 * 
	 * @return this builder
	 */
	OptionDocBuilder ordinal(final int i);
	
	/**
	 * Sets the format string for the usage of the {@code Option}.
	 * <p>
	 * The following are property keys that can be applied as expandable 
	 * properties within the provided format string:
	 * </p>
	 * <table border="1"><tr><th>Property Key(s)</th></tr>
	 * <tr><td>Property keys defined in {@link System#getProperties()}</td></tr>
	 * <tr><td>Property keys prefixed with the name of a package followed by a 
	 * dot (.) and the {@code PackageDoc}'s property key defined in 
	 * {@link org.climax.PackageDocPropertyKeys}.</td></tr>
	 * <tr><td>Property keys prefixed with the {@code String} representation of
	 * an {@link org.climax.OptionTypeDoc} followed by a dot (.) and the 
	 * {@link org.climax.OptionTypeDoc}'s property key defined in
	 * {@link org.climax.OptionTypeDocPropertyKeys}.</td></tr>
	 * <tr><td>{@link org.climax.OptionDocPropertyKeys#NAME}
	 * ({@value org.climax.OptionDocPropertyKeys#NAME})</td></tr> 
	 * <tr><td>{@link org.climax.OptionDocPropertyKeys#OPTION} 
	 * ({@value org.climax.OptionDocPropertyKeys#OPTION})</td></tr>
	 * <tr><td>Property keys prefixed with 
	 * {@link org.climax.OptionDocPropertyKeys#OPTIONTYPEDOC_PREFIX} 
	 * ({@value org.climax.OptionDocPropertyKeys#OPTIONTYPEDOC_PREFIX}) 
	 * followed by a dot (.) and an {@code OptionTypeDoc}'s property key 
	 * defined in {@link org.climax.OptionTypeDocPropertyKeys}.</td></tr>
	 * </table>
	 *  
	 * @param s the provided format string for the usage of the 
	 * {@code Option}
	 * 
	 * @return this builder
	 * 
	 * @see <a href="package-summary.html#3">Expandable Properties</a> 
	 */	
	OptionDocBuilder usage(final String s);
}