/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code OptionDoc}s by their 
 * {@code Option}s' names.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class OptionDocByOptionNameComparatorImpl 
	implements Comparator<OptionDoc> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code OptionDocComparatorHolder.OPTIONDOC_COMPARATOR}.
	 */
	private static final class OptionDocComparatorHolder {
		
		/** The {@code OptionDocByOptionNameComparatorImpl}. */
		static final OptionDocByOptionNameComparatorImpl OPTIONDOC_COMPARATOR =
				new OptionDocByOptionNameComparatorImpl();
		
		/**
		 * Constructs an {@code OptionDocComparatorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */	
		private OptionDocComparatorHolder() {
		}
	}
	
	/**
	 * Returns an {@code OptionDocByOptionNameComparatorImpl}.
	 * 
	 * @return an {@code OptionDocByOptionNameComparatorImpl}
	 */
	static OptionDocByOptionNameComparatorImpl getInstance() {
		return OptionDocComparatorHolder.OPTIONDOC_COMPARATOR;
	}
	
	/**
	 * Constructs an {@code OptionDocByOptionNameComparatorImpl}. This 
	 * constructor is suppressed for noninstantiability outside of this class.
	 */
	private OptionDocByOptionNameComparatorImpl() {
	}

	@Override
	public int compare(final OptionDoc o1, final OptionDoc o2) {
		Comparator<Option> comparator = 
				AbstractFactory.getDefault().getOptionByNameComparator();
		return comparator.compare(o1.getOption(), o2.getOption());
	}

}
