/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code OptionDoc}s first by their 
 * ordinals and then by their {@code Option}s.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class OptionDocComparatorImpl implements Comparator<OptionDoc> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code OptionDocComparatorHolder.OPTIONDOC_COMPARATOR}.
	 */
	private static final class OptionDocComparatorHolder {
		
		/** The {@code OptionDocComparatorImpl}. */
		static final OptionDocComparatorImpl OPTIONDOC_COMPARATOR =
				new OptionDocComparatorImpl();
		
		/**
		 * Constructs an {@code OptionDocComparatorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */	
		private OptionDocComparatorHolder() {
		}
	}
	
	/**
	 * Returns an {@code OptionDocComparatorImpl}.
	 * 
	 * @return an {@code OptionDocComparatorImpl}
	 */
	static OptionDocComparatorImpl getInstance() {
		return OptionDocComparatorHolder.OPTIONDOC_COMPARATOR;
	}
	
	/**
	 * Constructs an {@code OptionDocComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private OptionDocComparatorImpl() {
	}

	@Override
	public int compare(final OptionDoc o1, final OptionDoc o2) {
		int result = o1.getOrdinal() - o2.getOrdinal();
		if (result != 0) { return result; }
		Comparator<Option> comparator = 
				AbstractFactory.getDefault().getOptionComparator();
		return comparator.compare(o1.getOption(), o2.getOption());
	}

}
