/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * A builder for an {@code OptionGroup} of the specified parsed argument type.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 * @param <T> the specified parsed argument type
 */
public interface OptionGroupBuilder<T> {

	/**
	 * Sets the {@code ArgParser}.
	 * 
	 * @param p the provided {@code ArgParser}
	 * 
	 * @return this builder
	 */
	OptionGroupBuilder<T> argParser(final ArgParser<? extends T> p);
	
	/**
	 * Sets the format string for the argument separator.
	 * <p>
	 * The following are property keys that can be applied as expandable 
	 * properties within the provided format string:
	 * </p>
	 * <ul>
	 * <li>Property keys defined in {@link System#getProperties()}</li>
	 * </ul>
	 * 
	 * @param s the provided format string for the argument separator
	 * 
	 * @return this builder
	 */	
	OptionGroupBuilder<T> argSeparator(final String s);
	
	/**
	 * Sets the {@code ArgsValidator}.
	 * 
	 * @param v the provided {@code ArgsValidator}
	 * 
	 * @return this builder
	 */	
	OptionGroupBuilder<T> argsValidator(final ArgsValidator v);
	
	/**
	 * Builds a new {@code OptionGroup} of the specified parsed argument type.
	 * 
	 * @return a new {@code OptionGroup} of the specified parsed argument type
	 */
	OptionGroup<T> buildOptionGroup();
	
	/**
	 * Sets the default argument format strings with the provided {@code List} 
	 * of default argument format strings.
	 * <p>
	 * The following are property keys that can be applied as expandable 
	 * properties within the provided format strings:
	 * </p>
	 * <ul>
	 * <li>Property keys defined in {@link System#getProperties()}</li>
	 * </ul>
	 * 
	 * @param l the provided {@code List} of default argument format strings
	 * 
	 * @return this builder
	 */	
	OptionGroupBuilder<T> defaultArguments(final List<String> l);
	
	/**
	 * Sets the boolean value to indicate if the {@code OptionGroup}'s
	 * {@code OptionSelection}s of type {@code String} terminates 
	 * the parsing of any other command line argument.
	 * 
	 * @param b the provided boolean value to indicate if the 
	 * {@code OptionGroup}'s {@code OptionSelection}s of type 
	 * {@code String} terminates the parsing of any other command line 
	 * argument
	 * 
	 * @return this builder
	 */	
	OptionGroupBuilder<T> optionSelectionsTerminative(final boolean b);
}