/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * An {@code OptionGroup} of the specified parsed argument type and its 
 * {@code OptionGroupDoc}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 * @param <T> the specified parsed argument type
 */
public interface OptionGroupComplete<T> extends OptionGroup<T>, OptionGroupDoc {
	
	/**
	 * Returns an unmodifiable {@code List} of {@code OptionComplete}s.
	 * 
	 * @return an unmodifiable {@code List} of {@code OptionComplete}s
	 */
	List<OptionComplete> getOptionCompletes();	
	
	/**
	 * Indicates if the {@code OptionGroupDoc} is excluded from 
	 * documentation.
	 * 
	 * @return {@code true} if the
	 * {@link org.climax.OptionGroupCompleteBuilder#hidden(boolean)} 
	 * method is set to {@code true}; otherwise {@code false}
	 */
	boolean isHidden();
	
	/**
	 * Indicates if the {@code OptionGroup} is excluded from parsing.
	 * 
	 * @return {@code true} if the
	 * {@link org.climax.OptionGroupCompleteBuilder#unused(boolean)} 
	 * method is set to {@code true}; otherwise {@code false}
	 */
	boolean isUnused();
}
