/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * A builder for an {@code OptionGroupComplete} of the specified parsed 
 * argument type.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 * @param <T> the specified parsed argument type
 */
public interface OptionGroupCompleteBuilder<T> 
	extends OptionGroupBuilder<T>, OptionGroupDocBuilder {

	@Override
	OptionGroupCompleteBuilder<T> argParser(final ArgParser<? extends T> p);
	
	@Override	
	OptionGroupCompleteBuilder<T> argSeparator(final String s);
	
	@Override	
	OptionGroupCompleteBuilder<T> argsValidator(final ArgsValidator v);
	
	/**
	 * Builds a new {@code OptionGroupComplete} of the specified parsed 
	 * argument type.
	 * 
	 * @return a new {@code OptionGroupComplete} of the specified parsed 
	 * argument type
	 */
	OptionGroupComplete<T> buildOptionGroupComplete();
	
	@Override	
	OptionGroupCompleteBuilder<T> defaultArguments(final List<String> l);
	
	@Override	
	OptionGroupCompleteBuilder<T> description(final String s);
	
	@Override	
	OptionGroupCompleteBuilder<T> help(final String s);
	
	/**
	 * Sets the boolean value to indicate if the {@code OptionGroupDoc} 
	 * is excluded from documentation.
	 * 
	 * @param b the provided boolean value to indicate if the 
	 * {@code OptionGroupDoc} is excluded from documentation
	 * 
	 * @return this builder
	 */
	OptionGroupCompleteBuilder<T> hidden(final boolean b);
	
	@Override	
	OptionGroupCompleteBuilder<T> optionSelectionsTerminative(final boolean b);	
	
	@Override	
	OptionGroupCompleteBuilder<T> ordinal(final int i);
	
	/**
	 * Sets the boolean value to indicate if the {@code OptionGroup} is 
	 * excluded from parsing.
	 * 
	 * @param b the provided boolean value to indicate if the 
	 * {@code OptionGroup} is excluded from parsing
	 * 
	 * @return this builder
	 */
	OptionGroupCompleteBuilder<T> unused(final boolean b);
	
	@Override	
	OptionGroupCompleteBuilder<T> usage(final String s);
}
