/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * The documentation for an {@code OptionGroupDoc}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public interface OptionGroupDoc extends Doc {

	/**
	 * Returns the description for the {@code OptionGroup}.
	 * 
	 * @return the description for the {@code OptionGroup}
	 */
	String getDescription();

	/**
	 * Returns the help information for the {@code OptionGroup}.
	 * 
	 * @return the help information for the {@code OptionGroup}
	 */
	String getHelp();

	/**
	 * Returns a sorted unmodifiable list of {@code OptionDoc}s.
	 * 
	 * @return a sorted unmodifiable list of {@code OptionDoc}s
	 */
	List<OptionDoc> getOptionDocs();
	
	/**
	 * Returns the ordinal of this {@code OptionGroupDoc} in relation 
	 * to other {@code OptionGroupDoc}s.
	 * 
	 * @return the ordinal of this {@code OptionGroupDoc} in relation 
	 * to other {@code OptionGroupDoc}s
	 */
	int getOrdinal();
	
	/**
	 * Returns the usage for the {@code OptionGroup}.
	 * 
	 * @return the usage for the {@code OptionGroup}
	 */
	String getUsage();
}
