/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;
import java.util.List;

/**
 * A {@code Comparator} that compares two {@code OptionGroupDoc}s first by 
 * their ordinals and then by their {@code OptionDoc}s' {@code Option}s' 
 * names.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class OptionGroupDocComparatorImpl 
	implements Comparator<OptionGroupDoc> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code OptionGroupDocComparatorHolder.OPTIONGROUPDOC_COMPARATOR}.
	 */
	private static final class OptionGroupDocComparatorHolder {
		
		/** The {@code OptionGroupDocComparatorImpl}. */
		static final OptionGroupDocComparatorImpl OPTIONGROUPDOC_COMPARATOR = 
				new OptionGroupDocComparatorImpl();
		
		/**
		 * Constructs an {@code OptionGroupDocComparatorHolder}. This 
		 * constructor is suppressed for noninstantiability outside of 
		 * this class.
		 */
		private OptionGroupDocComparatorHolder() {
		}
	}
	
	/**
	 * Returns an {@code OptionGroupDocComparatorImpl}.
	 * 
	 * @return an {@code OptionGroupDocComparatorImpl}
	 */
	static OptionGroupDocComparatorImpl getInstance() {
		return OptionGroupDocComparatorHolder.OPTIONGROUPDOC_COMPARATOR;
	}
	
	/**
	 * Constructs an {@code OptionGroupDocComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private OptionGroupDocComparatorImpl() {
	}
	
	@Override
	public int compare(final OptionGroupDoc o1, final OptionGroupDoc o2) {
		
		int result = o1.getOrdinal() - o2.getOrdinal();

		if (result != 0) { return result; }
		
		List<OptionDoc> list1 = o1.getOptionDocs();
		List<OptionDoc> list2 = o2.getOptionDocs();
		
		int size1 = list1.size();
		int size2 = list2.size();
		
		int sizeDiff = size1 - size2;
		
		int smallerSize = size1;
		
		if (sizeDiff > 0) { smallerSize = size2; }
		
		AbstractFactory factory = AbstractFactory.getDefault();
		
		Comparator<OptionDoc> comparator =  
				factory.getOptionDocByOptionNameComparator();
		
		for (int i = 0; i < smallerSize; i++) {
			result = comparator.compare(list1.get(i), list2.get(i));
			if (result != 0) { return result; }
		}
		
		return sizeDiff;
	}

}
