/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Thrown when an {@code OptionGroup}'s {@code OptionSelection}s of type 
 * {@code String} are invalid or cannot be parsed.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class OptionGroupException extends Exception {

	/** The default serial version UID. */
	private static final long serialVersionUID = 1L;

	/** 
	 * The {@code List} of OptionSelection}s of type {@code String} that 
	 * are invalid or cannot be parsed.
	 */
	private final List<OptionSelection<String>> optionSelectionList;
	
	/**
	 * Constructs an {@code OptionGroupException} with the provided 
	 * {@code List} of {@code OptionSelection}s of type {@code String} that are
	 * invalid or cannot be parsed and the specified detail message.
	 * 
	 * @param optionSelectList the {@code List} of {@code OptionSelection}s of 
	 * type {@code String} that are invalid or cannot be parsed
	 * 
	 * @param message the detail message
	 */
	public OptionGroupException(
			final List<OptionSelection<String>> optionSelectList,
			final String message) {
		
		this(optionSelectList, message, null);
	}
	
	/**
	 * Constructs an {@code OptionGroupException} with the provided 
	 * {@code List} of {@code OptionSelection}s of type {@code String} that are 
	 * invalid or cannot be parsed, the specified detail message, and the 
	 * optional {@code Throwable} that was raised.
	 * 
	 * @param optionSelectList the {@code List} of {@code OptionSelection}s of 
	 * type {@code String} that are invalid or cannot be parsed
	 * 
	 * @param message the detail message
	 * 
	 * @param cause the {@code Throwable} that was raised
	 */
	public OptionGroupException(
			final List<OptionSelection<String>> optionSelectList,
			final String message,
			final Throwable cause) {
		
		super(message, cause);
		
		this.optionSelectionList = 
				new ArrayList<OptionSelection<String>>();
		
		this.optionSelectionList.addAll(optionSelectList);
	}
	
	/**
	 * Returns an unmodifiable {@code List} of {@code OptionSelection}s 
	 * of type {@code String} that are invalid or cannot be parsed.
	 * 
	 * @return an unmodifiable {@code List} of {@code OptionSelection}s 
	 * of type {@code String} that are invalid or cannot be parsed
	 */
	public List<OptionSelection<String>> getOptionSelections() {
		return Collections.unmodifiableList(this.optionSelectionList);
	}
}
