/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

/**
 * An implementation of an {@code OptionSelection} of the specified 
 * type.
 * 
 * @author Climax Development (climax.development@gmail.com)
 * 
 * @param <T> the specified type
 */
final class OptionSelectionImpl<T> implements OptionSelection<T> {
	
	/** The {@code Option} from the {@code OptionGroup}. */
	private final Option option;
	
	/** The optional argument. */
	private final T argument;
	
	/**
	 * Constructs an {@code OptionSelectionImpl} with the provided 
	 * {@code Option} from the {@code OptionGroup} and the optional 
	 * argument.
	 * 
	 * @param opt the provided {@code Option} from the 
	 * {@code OptionGroup}
	 * 
	 * @param arg the optional argument
	 */
	OptionSelectionImpl(final Option opt, final T arg) {
		
		if (opt == null) {
			throw new NullPointerException("option must not be null");
		}
		
		this.option = opt;
		
		this.argument = arg;
	}
	
	@Override
	public T getArgument() {
		return this.argument;
	}
	
	@Override
	public Option getOption() {
		return this.option;
	}

	@Override
	public String toString() {
		return String.format("OptionSelection [option=%s, argument=%s]",
				this.option, this.argument);
	}
}