/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;


/**
 * A command line option type. The constants of this enumerated type 
 * provide a simple classification of the command line option types.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public enum OptionType {
	
	/** 
	 * POSIX option, such as -h, -v, -oFILE. 
	 */
	POSIX("-", ""),
	
	/** 
	 * Short GNU long option, such as -help, -version, -output-file FILE. 
	 */
	GNU_SHORT_LONG("-", " "),
	
	/** 
	 * GNU long option, such as --help, --version, --output-file=FILE. 
	 */
	GNU_LONG("--", "=");

	/**
	 * The delimiter that indicates that the argument is a
	 * command line option of this {@code OptionType}.
	 */
	private final String optionDelimiter;
	
	/**
	 * The assignment operator that assigns the argument to right 
	 * of the operator to the option to the left of the operator.
	 */		
	private final String optionAssignmentOperator;
	
	/**
	 * Constructs an {@code OptionType} with the provided delimiter 
	 * and the provided assignment operator.
	 *  
	 * @param delimiter the provided delimiter that indicates that the 
	 * argument is a command line option of this {@code OptionType}
	 * 
	 * @param assignmentOperator the provided assignment operator that 
	 * assigns the argument to right of the operator to the option to 
	 * the left of the operator
	 */
	private OptionType(
			final String delimiter, final String assignmentOperator) {
		
		this.optionDelimiter = delimiter;
		this.optionAssignmentOperator = assignmentOperator;
	}
	
	/**
	 * Returns the assignment operator that assigns the argument to right 
	 * of the operator to the option to the left of the operator.
	 * 
	 * @return the assignment operator that assigns the argument to right 
	 * of the operator to the option to the left of the operator
	 */
	public String getAssignmentOperator() {
		return this.optionAssignmentOperator;
	}
	
	/**
	 * Returns the delimiter that indicates that the argument is a
	 * command line option of this {@code OptionType}.
	 * 
	 * @return the delimiter that indicates that the argument is a
	 * command line option of this {@code OptionType}.
	 */
	public String getDelimiter() {
		return this.optionDelimiter;
	}
}