/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.List;

/**
 * A group of {@code OptionGroup}s.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public interface Options {
	
	/**
	 * Adds an {@code OptionGroup} to this {@code Options}.
	 * 
	 * @param optionGroup the provided {@code OptionGroup} 
	 */
	void addOptionGroup(final OptionGroup<? extends Object> optionGroup);
	
	/**
	 * Returns an unmodifiable {@code List} of {@code OptionGroup}s.
	 * 
	 * @return an unmodifiable {@code List} of {@code OptionGroup}s.
	 */
	List<OptionGroup<Object>> getOptionGroups();
	
	/**
	 * Returns an unmodifiable {@code List} of {@code Option}s.
	 * 
	 * @return an unmodifiable {@code List} of {@code Option}s
	 */
	List<Option> getOptions();
	
	/**
	 * Returns the command line arguments that are not command line options 
	 * nor their arguments.
	 * 
	 * @return the command line arguments that are not command line options 
	 * nor their arguments
	 */
	String[] getRemainingArguments();
	
	/**
	 * Parses from the command line arguments the command line options and 
	 * their arguments.
	 * 
	 * @param args the command line arguments
	 * 
	 * @throws OptionsException if one of the command line options is 
	 * invalid or cannot be parsed or if their arguments are invalid or 
	 * cannot be parsed or if one of the command line options is required
	 */
	void parse(final String[] args) throws OptionsException;
}
