/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code Package}s by their names.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class PackageComparatorImpl implements Comparator<Package> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code PackageComparatorHolder.PACKAGE_COMPARATOR}.
	 */
	private static final class PackageComparatorHolder {
		
		/** The {@code PackageComparatorImpl}. */
		static final PackageComparatorImpl PACKAGE_COMPARATOR =
				new PackageComparatorImpl();

		/**
		 * Constructs a {@code PackageComparatorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */	
		private PackageComparatorHolder() {
		}
	}
	
	/**
	 * Returns a {@code PackageComparatorImpl}.
	 * 
	 * @return a {@code PackageComparatorImpl}
	 */
	static PackageComparatorImpl getInstance() {
		return PackageComparatorHolder.PACKAGE_COMPARATOR;
	}
	
	/**
	 * Constructs a {@code PackageComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private PackageComparatorImpl() {
	}

	@Override
	public int compare(final Package o1, final Package o2) {
		return o1.getName().compareTo(o2.getName());
	}

}
