/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Comparator;

/**
 * A {@code Comparator} that compares two {@code PackageDoc}s by their 
 * {@code Package}s.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class PackageDocComparatorImpl implements Comparator<PackageDoc> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code PackageDocComparatorHolder.PACKAGEDOC_COMPARATOR}.
	 */
	private static final class PackageDocComparatorHolder {
		
		/** The {@code PackageDocComparatorImpl}. */
		static final PackageDocComparatorImpl PACKAGEDOC_COMPARATOR =
				new PackageDocComparatorImpl();

		/**
		 * Constructs a {@code PackageDocComparatorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */	
		private PackageDocComparatorHolder() {
		}
	}
	
	/**
	 * Returns a {@code PackageDocComparatorImpl}.
	 * 
	 * @return a {@code PackageDocComparatorImpl}
	 */
	static PackageDocComparatorImpl getInstance() {
		return PackageDocComparatorHolder.PACKAGEDOC_COMPARATOR;
	}
	
	/**
	 * Constructs a {@code PackageDocComparatorImpl}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private PackageDocComparatorImpl() {
	}

	@Override
	public int compare(final PackageDoc o1, final PackageDoc o2) {
		Comparator<Package> comparator = 
				AbstractFactory.getDefault().getPackageComparator();
		return comparator.compare(o1.getPackage(), o2.getPackage());
	}

}
