/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

/**
 * This class contains all of the property keys for a {@code PackageDoc}'s 
 * documentation properties.  
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class PackageDocPropertyKeys {

	/** 
	 * The property key for the title of the package. 
	 */
	public static final String IMPL_TITLE = "implTitle";
	
	/** 
	 * The property key for the name of the organization, vendor, or company 
	 * that provided the package's implementation. 
	 */
	public static final String IMPL_VENDOR = "implVendor";
	
	/**
	 * The property key for the version of the package's implementation. 
	 */
	public static final String IMPL_VERSION = "implVersion";
	
	/** 
	 * The property key for the title of the specification that the package 
	 * implements.
	 */
	public static final String SPEC_TITLE = "specTitle";
	
	/**
	 * The property key for the name of the organization, vendor, or company 
	 * that owns and maintains the specification of the classes that implements 
	 * the package.
	 */
	public static final String SPEC_VENDOR = "specVendor";
	
	/** 
	 * The property key for the version number of the specification that the 
	 * package implements.
	 */
	public static final String SPEC_VERSION = "specVersion";
	
	/**
	 * Constructs an instance of {@code PackageDocPropertyKeys}. This 
	 * constructor is suppressed for noninstantiability outside of this class.
	 */	
	private PackageDocPropertyKeys() {
	}
}
