/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

/**
 * Thrown when an error in expanding a {@code String} is encountered.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class StringExpansionException extends RuntimeException {

	/** The default serial version UID. */
	private static final long serialVersionUID = 1L;
	
	/** The substring that causes the error. */
	private final String substring;
	
	/**
	 * Constructs a {@code StringExpansionException} with the provided 
	 * substring that causes the error and the specified detail message.
	 * 
	 * @param substr the provided substring that causes the error
	 * 
	 * @param message the detail message
	 */
	public StringExpansionException(
			final String substr, final String message) {
		
		super(message);
		this.substring = substr;
	}
	
	/**
	 * Constructs a {@code StringExpansionException} with the provided
	 * substring that causes the error, the specified detail message, and the 
	 * {@code Throwable} that was raised.
	 * 
	 * @param substr the provided substring that causes the error
	 * 
	 * @param message the detail message
	 * 
	 * @param cause the {@code Throwable} that was raised
	 */
	public StringExpansionException(
			final String substr, 
			final String message, 
			final Throwable cause) {
		
		super(message, cause);
		this.substring = substr;
	}
	
	/**
	 * Returns the substring that causes the error.
	 * 
	 * @return the substring that causes the error
	 */
	public String getSubstring() {
		return this.substring;
	}

}
