/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Collections;
import java.util.Map;

/**
 * An implementation of {@code SystemDoc}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 */
final class SystemDocImpl implements SystemDoc {

	/** 
	 * Lazy initialization holder class idiom for static field for
	 * {@code SystemDocImplHolder.SYSTEM_DOC}.
	 */
	private static final class SystemDocImplHolder {

		/** The {@code SystemDocImpl}. */
		static final SystemDocImpl SYSTEM_DOC = new SystemDocImpl();
		
		/**
		 * Constructs a {@code SystemDocImplHolder}. This constructor 
		 * is suppressed for noninstantiability outside of this class.
		 */
		private SystemDocImplHolder() {
		}
	}
	
	/**
	 * Returns a {@code SystemDocImpl}.
	 * 
	 * @return a {@code SystemDocImpl}
	 */
	static SystemDocImpl getInstance() {
		return SystemDocImplHolder.SYSTEM_DOC;
	}
	
	/**
	 * Returns an unmodifiable {@code Map} for the documentation properties 
	 * of the {@code SystemDocImpl}.
	 * 
	 * @return an unmodifiable {@code Map} for the documentation properties 
	 * of the {@code SystemDocImpl}
	 */
	static Map<String, String> getSystemDocImplProperties() {
		return SystemDocImplHolder.SYSTEM_DOC.getProperties();
	}
	
	/**
	 * The {@code Map} for the documentation properties of this 
	 * {@code SystemDocImpl}.
	 */
	private final Map<String, String> properties;
	
	/**
	 * Constructs a {@code SystemDocImpl}.
	 */
	private SystemDocImpl() {
		
		Map<String, String> props = new Properties();
		
		java.util.Properties p = System.getProperties(); 
		
		for (String propertyName : p.stringPropertyNames()) {
			
			String propertyValue = p.getProperty(propertyName);
			
			props.put(propertyName, propertyValue);
		}
		
		this.properties = props;
	}
	
	
	@Override
	public Map<String, String> getProperties() {
		return Collections.unmodifiableMap(this.properties);
	}

	/**
	 * Returns a {@code String} representation of this {@code SystemDocImpl}. 
	 * The details of this representation are unspecified and subject to 
	 * change.
	 * 
	 * @return a {@code String} representation of this {@code SystemDocImpl}
	 */
	@Override
	public String toString() {
		return String.format("SystemDoc [properties=%s]", this.properties);
	}

}
