/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import java.util.Map;

/**
 * This class provides static utility methods for this package.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class Util {
	
	/**
	 * Expands within a provided string the expandable properties whose 
	 * keys and associated values are defined by a provided {@code Map}.
	 * 
	 * @param string the provided string
	 * 
	 * @param map the provided {@code Map} that defines the expandable 
	 * properties' keys and their associated values
	 * 
	 * @return the expanded string
	 */
	static String expand1(
			final String string, final Map<String, String> map) {
		
		Map<String, String> properties = new Properties(map);
		
		return StringExpander.expand(string, properties);		
	}
	
	/**
	 * Expands within a provided string the following expandable properties: 
	 * system properties and additional properties whose keys and associated 
	 * values are defined by a provided {@code Map}.
	 * 
	 * @param string the provided string
	 * 
	 * @param map the provided {@code Map} that defines the additional 
	 * properties' keys and their associated values
	 * 
	 * @return the expanded string
	 */
	static String expand2(
			final String string, final Map<String, String> map) {
		
		Map<String, String> properties = new Properties(map);
		
		properties.putAll(
				AbstractFactory.getDefault().getSystemDocProperties());
		
		return Util.expand1(string, properties);
	}
	
	/**
	 * Expands within a provided string the following expandable properties: 
	 * system properties, the {@code PackageDoc}s' documentation properties, 
	 * and additional properties whose keys and associated values are 
	 * defined by a provided {@code Map}.
	 * 
	 * @param string the provided string
	 * 
	 * @param map the provided {@code Map} that defines the additional 
	 * properties' keys and their associated values
	 * 
	 * @return the expanded string
	 */
	static String expand3(
			final String string, final Map<String, String> map) {
		
		Map<String, String> properties = new Properties(map);
		
		properties.putAll(
				AbstractFactory.getDefault().getPackageDocsProperties());
		
		return Util.expand2(string, properties);
	}
	
	/**
	 * Expands within a provided string the following expandable properties: 
	 * system properties, the {@code PackageDoc}s' documentation properties, 
	 * the {@code OptionTypeDoc}s' documentation properties, and additional 
	 * properties whose keys and associated values are defined by a provided 
	 * {@code Map}.
	 * 
	 * @param string the provided string
	 * 
	 * @param map the provided {@code Map} that defines the additional 
	 * properties' keys and their associated values
	 * 
	 * @return the expanded string
	 */
	static String expand4(
			final String string, final Map<String, String> map) {
		
		Map<String, String> properties = new Properties(map);
		
		properties.putAll(OptionTypeDoc.getOptionTypeDocsProperties());
		
		return Util.expand3(string, properties);
	}
	
	/**
	 * Constructs an instance of {@code Util}. This constructor is 
	 * suppressed for noninstantiability outside of this class.
	 */
	private Util() {
	}
}
