/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an argument whose 
 * index is after the first index.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class AfterFirstArgIndexAcceptor 
	implements ParameterlessArgAcceptor {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgAcceptorHolder.ARG_ACCEPTOR}.
	 */
	private static final class ArgAcceptorHolder {
	
		/** The {@code ArgAcceptor}. */
		static final AfterFirstArgIndexAcceptor ARG_ACCEPTOR = 
			new AfterFirstArgIndexAcceptor(); 
		
		/**
		 * Constructs an {@code ArgAcceptorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgAcceptorHolder() {
		}
	}
	
	/**
	 * Returns an {@code AfterFirstArgIndexAcceptor}.
	 * 
	 * @return an {@code AfterFirstArgIndexAcceptor}
	 */
	public static AfterFirstArgIndexAcceptor getInstance() {
		return ArgAcceptorHolder.ARG_ACCEPTOR;
	}
	
	/** The {@code ArgAcceptor}. */
	private final ArgAcceptor argAcceptor;
	
	/**
	 * Constructs an {@code AfterFirstArgIndexAcceptor}.
	 */
	public AfterFirstArgIndexAcceptor() {
		this.argAcceptor = new NegationArgAcceptor(new FirstArgIndexAcceptor());
	}

	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return this.argAcceptor.canAccept(context);
	}

}
