/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an argument based 
 * on its index.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class ArgIndexAcceptor implements ArgAcceptor {

	/** The argument index. */
	private final int argumentIndex;
	
	/**
	 * Constructs an {@code ArgIndexAcceptor} with the provided argument 
	 * index.
	 * 
	 * @param index the provided argument index
	 */
	public ArgIndexAcceptor(final int index) {
		
		if (index < 0) {
			throw new IndexOutOfBoundsException("index must be at least 0");
		}
		
		this.argumentIndex = index;
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return this.argumentIndex == context.getIndex();
	}

}
