/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an argument whose 
 * index is before the last index.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class BeforeLastArgIndexAcceptor 
	implements ParameterlessArgAcceptor {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgAcceptorHolder.ARG_ACCEPTOR}.
	 */
	private static final class ArgAcceptorHolder {
	
		/** The {@code ArgAcceptor}. */
		static final BeforeLastArgIndexAcceptor ARG_ACCEPTOR = 
			new BeforeLastArgIndexAcceptor(); 
		
		/**
		 * Constructs an {@code ArgAcceptorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgAcceptorHolder() {
		}
	}
	
	/**
	 * Returns a {@code BeforeLastArgIndexAcceptor}.
	 * 
	 * @return a {@code BeforeLastArgIndexAcceptor}
	 */
	public static BeforeLastArgIndexAcceptor getInstance() {
		return ArgAcceptorHolder.ARG_ACCEPTOR;
	}

	/** The {@code ArgAcceptor}. */
	private final ArgAcceptor argAcceptor;
	
	/**
	 * Constructs a {@code BeforeLastArgIndexAcceptor}.
	 */
	public BeforeLastArgIndexAcceptor() {
		this.argAcceptor = new NegationArgAcceptor(new LastArgIndexAcceptor());
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return this.argAcceptor.canAccept(context);
	}

}
