/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an argument whose
 * index is the last.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class LastArgIndexAcceptor implements ParameterlessArgAcceptor {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgAcceptorHolder.ARG_ACCEPTOR}.
	 */
	private static final class ArgAcceptorHolder {
	
		/** The {@code ArgAcceptor}. */
		static final LastArgIndexAcceptor ARG_ACCEPTOR = 
			new LastArgIndexAcceptor(); 
		
		/**
		 * Constructs an {@code ArgAcceptorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgAcceptorHolder() {
		}
	}
	
	/**
	 * Returns a {@code LastArgIndexAcceptor}.
	 * 
	 * @return a {@code LastArgIndexAcceptor}
	 */
	public static LastArgIndexAcceptor getInstance() {
		return ArgAcceptorHolder.ARG_ACCEPTOR;
	}

	/**
	 * Constructs a {@code LastArgIndexAcceptor}.
	 */
	public LastArgIndexAcceptor() {
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return context.getIndex() == context.getArguments().length - 1;
	}

}
