/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an argument whose
 * index is the provided maximum index or below the provided maximum index.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public final class MaxArgIndexAcceptor implements ArgAcceptor {

	/** The maximum argument index. */
	private final int maximumArgumentIndex;
	
	/**
	 * Constructs a {@code MaxArgIndexAcceptor} with the provided maximum
	 * index.
	 * 
	 * @param maxArgIndex the provided maximum index
	 */
	public MaxArgIndexAcceptor(final int maxArgIndex) {
		
		if (maxArgIndex < 0) {
			throw new IndexOutOfBoundsException(
					"maxArgIndex must be at least 0");			
		}
		
		this.maximumArgumentIndex = maxArgIndex;
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return context.getIndex() <= this.maximumArgumentIndex;
	}

}
