/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an argument whose
 * index is the provided minimum index or above the provided minimum index.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public final class MinArgIndexAcceptor implements ArgAcceptor {

	/** The minimum argument index. */
	private final int minimumArgumentIndex;
	
	/**
	 * Constructs a {@code MinArgIndexAcceptor} with the provided minimum
	 * index.
	 * 
	 * @param minArgIndex the provided minimum index
	 */
	public MinArgIndexAcceptor(final int minArgIndex) {
		
		if (minArgIndex < 0) {
			throw new IndexOutOfBoundsException(
					"minArgIndex must be at least 0");
		}
		
		this.minimumArgumentIndex = minArgIndex;
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return context.getIndex() >= this.minimumArgumentIndex;
	}

}
