/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that negates the result from the
 * contained {@code ArgAcceptor}. 
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class NegationArgAcceptor implements ArgAcceptor {

	/** The {@code ArgAcceptor}. */
	private final ArgAcceptor argAcceptor;
	
	/**
	 * Constructs a {@code NegationArgAcceptor} with the provided
	 * {@code ArgAcceptor}.
	 * 
	 * @param acceptor the provided {@code ArgAcceptor}
	 */
	public NegationArgAcceptor(final ArgAcceptor acceptor) {
		
		if (acceptor == null) {
			throw new NullPointerException("acceptor must not be null");
		}
		
		this.argAcceptor = acceptor;
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return !this.argAcceptor.canAccept(context);
	}

}
