/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept no arguments.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class NoArgAcceptor implements ParameterlessArgAcceptor {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgAcceptorHolder.ARG_ACCEPTOR}.
	 */
	private static final class ArgAcceptorHolder {
	
		/** The {@code ArgAcceptor}. */
		static final NoArgAcceptor ARG_ACCEPTOR = 
			new NoArgAcceptor(); 
		
		/**
		 * Constructs an {@code ArgAcceptorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgAcceptorHolder() {
		}
	}
	
	/**
	 * Returns an {@code NoArgAcceptor}.
	 * 
	 * @return an {@code NoArgAcceptor}
	 */
	public static NoArgAcceptor getInstance() {
		return ArgAcceptorHolder.ARG_ACCEPTOR;
	}

	/**
	 * Constructs a {@code NoArgAcceptor}.
	 */
	public NoArgAcceptor() {
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return false;
	}

}
