/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an argument at 
 * every <i>n</i>th index.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public final class OrdinalRecurringArgAcceptor implements ArgAcceptor {

	/** The ordinal. */
	private final int ordinal;
	
	/**
	 * Constructs an {@code OrdinalRecurringArgAcceptor} with the provided
	 * ordinal.
	 * 
	 * @param ord the provided ordinal
	 */
	public OrdinalRecurringArgAcceptor(final int ord) {
		
		if (ord < 1) {
			throw new IllegalArgumentException("ord must be at least 1");
		}
		
		this.ordinal = ord;
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return (context.getIndex() + 1) % this.ordinal == 0;
	}

}
