/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptor;
import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept only one argument
 * throughout multiple invocations.
 * <p> 
 * This {@code ArgAcceptor} uses a {@code LimitedArgAcceptor} instance. 
 * Please see {@link org.climax.argacceptor.LimitedArgAcceptor} for details.
 * </p>
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public final class SingleArgAcceptor implements ParameterlessArgAcceptor {
	
	/**
	 * Returns a new {@code SingleArgAcceptor}.
	 * 
	 * @return a new {@code SingleArgAcceptor}
	 */
	public static SingleArgAcceptor newInstance() {
		return new SingleArgAcceptor();
	}

	/** The {@code ArgAcceptor}. */
	private final ArgAcceptor argAcceptor;
	
	/**
	 * Constructs a {@code SingleArgAcceptor}.
	 */
	public SingleArgAcceptor() {
		this.argAcceptor = new LimitedArgAcceptor(1);
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return this.argAcceptor.canAccept(context);
	}

}
