/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argacceptor;

import org.climax.ArgAcceptorContext;

/**
 * An {@code ArgAcceptor} implementation that can accept an unlimited number of
 * arguments throughout multiple invocations.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public final class UnlimitedArgAcceptor implements ParameterlessArgAcceptor {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgAcceptorHolder.ARG_ACCEPTOR}.
	 */
	private static final class ArgAcceptorHolder {
	
		/** The {@code ArgAcceptor}. */
		static final UnlimitedArgAcceptor ARG_ACCEPTOR = 
			new UnlimitedArgAcceptor(); 
		
		/**
		 * Constructs an {@code ArgAcceptorHolder}. This constructor is 
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgAcceptorHolder() {
		}
	}
	
	/**
	 * Returns an {@code UnlimitedArgAcceptor}.
	 * 
	 * @return an {@code UnlimitedArgAcceptor}
	 */
	public static UnlimitedArgAcceptor getInstance() {
		return ArgAcceptorHolder.ARG_ACCEPTOR;
	}

	/**
	 * Constructs an {@code UnlimitedArgAcceptor}.
	 */
	public UnlimitedArgAcceptor() {
	}
	
	@Override
	public boolean canAccept(final ArgAcceptorContext context) {
		return true;
	}

}
