/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argparser;

import org.climax.ArgParserException;

/**
 * An {@code ArgParser} implementation that parses an argument as a
 * {@code Boolean}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class BooleanArgParser 
	implements ParameterlessArgParser<Boolean> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgParserHolder.ARG_PARSER}.
	 */
	private static final class ArgParserHolder {
		
		/** The {@code ArgParser}. */
		static final BooleanArgParser ARG_PARSER =
			new BooleanArgParser();
		
		/**
		 * Constructs an {@code ArgParserHolder}. This constructor is
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgParserHolder() {
		}
	}
	
	/**
	 * Returns a {@code BooleanArgParser}.
	 * 
	 * @return a {@code BooleanArgParser}
	 */	
	public static BooleanArgParser getInstance() {
		return ArgParserHolder.ARG_PARSER;
	}
	
	/**
	 * Constructs a {@code BooleanArgParser}.
	 */
	public BooleanArgParser() {
	}
	
	@Override
	public Boolean parse(final String arg) throws ArgParserException {
		
		boolean isSpecifiedTrue =
			arg.equalsIgnoreCase(Boolean.TRUE.toString());
		
		boolean isSpecifiedFalse =
			arg.equalsIgnoreCase(Boolean.FALSE.toString());
		
		if (!isSpecifiedTrue && !isSpecifiedFalse) {
			
			String message = String.format(
					"argument must be either of the following: %1$s, %2$s", 
					Boolean.TRUE.toString(),
					Boolean.FALSE.toString());
			
			throw new ArgParserException(arg, message);
		}
		
		return Boolean.valueOf(arg);
	}
}
