/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argparser;

import org.climax.ArgParserException;

/**
 * An {@code ArgParser} implementation that parses an argument as a
 * {@code Character}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class CharacterArgParser 
	implements ParameterlessArgParser<Character> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgParserHolder.ARG_PARSER}.
	 */
	private static final class ArgParserHolder {
		
		/** The {@code ArgParser}. */
		static final CharacterArgParser ARG_PARSER =
			new CharacterArgParser();
		
		/**
		 * Constructs an {@code ArgParserHolder}. This constructor is
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgParserHolder() {
		}
	}
	
	/**
	 * Returns a {@code CharacterArgParser}.
	 * 
	 * @return a {@code CharacterArgParser}
	 */	
	public static CharacterArgParser getInstance() {
		return ArgParserHolder.ARG_PARSER;
	}

	/**
	 * Constructs a {@code CharacterArgParser}.
	 */
	public CharacterArgParser() {
	}
	
	@Override
	public Character parse(final String arg) throws ArgParserException {
		
		if (arg.isEmpty()) {
			
			String message = "argument must be non-empty";
			
			throw new ArgParserException(arg, message);
		}
		
		if (!arg.isEmpty() && arg.length() != 1) {
			
			String message = "argument must be a character";
			
			throw new ArgParserException(arg, message);
		}
		
		Character character = Character.valueOf(arg.charAt(0));

		return character;
	}

}
