/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argparser;

import org.climax.ArgParser;
import org.climax.ArgParserException;

/**
 * An {@code ArgParser} implementation that parses an argument as 
 * a {@code null} pointer of a specified type.
 * 
 * @author Climax Development (climax.development@gmail.com)
 *
 * @param <T> the specified type
 */
public final class NullArgParser<T> implements ArgParser<T> {
	
	/**
	 * Returns a new {@code NullArgParser} of the specified type.
	 * 
	 * @param <T> the specified type
	 * @return a new {@code NullArgParser} of the specified type
	 */	
	public static <T> NullArgParser<T> newInstance() {
		return new NullArgParser<T>();
	}
	
	/**
	 * Constructs a {@code NullArgParser}.
	 */
	public NullArgParser() {
	}
	
	@Override
	public T parse(final String arg) throws ArgParserException {

		return null;
	}

}
