/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argparser;

import org.climax.ArgParserException;

/**
 * An {@code ArgParser} implementation that parses an argument as a
 * {@code Void}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class VoidArgParser implements ParameterlessArgParser<Void> {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgParserHolder.ARG_PARSER}.
	 */
	private static final class ArgParserHolder {
		
		/** The {@code ArgParser}. */
		static final VoidArgParser ARG_PARSER =
			new VoidArgParser();
		
		/**
		 * Constructs an {@code ArgParserHolder}. This constructor is
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgParserHolder() {
		}
	}
	
	/**
	 * Returns a {@code VoidArgParser}.
	 * 
	 * @return a {@code VoidArgParser}
	 */	
	public static VoidArgParser getInstance() {
		return ArgParserHolder.ARG_PARSER;
	}

	/**
	 * Constructs a {@code VoidArgParser}.
	 */
	public VoidArgParser() {
	}
	
	@Override
	public Void parse(final String arg) throws ArgParserException {
		return null;
	}

}
