/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argsvalidator;

import java.util.List;

import org.climax.ArgsValidator;
import org.climax.ArgsValidatorException;

/**
 * An {@code ArgsValidator} that validates a {@code List} of arguments and 
 * invokes a contained {@code ArgsValidator}, if any, to validate the 
 * {@code List} of arguments.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public abstract class AbstractArgsValidator implements ArgsValidator {
	
	/** The contained {@code ArgsValidator}. */
	private final ArgsValidator argsValidator;
	
	/**
	 * Constructs an {@code AbstractArgsValidator} with the provided
	 * {@code ArgsValidator}.
	 * 
	 * @param validator the provided {@code ArgsValidator}
	 */
	protected AbstractArgsValidator(final ArgsValidator validator) {
		
		this.argsValidator = validator;
	}

	/**
	 * Returns the contained {@code ArgsValidator}.
	 * 
	 * @return the contained {@code ArgsValidator}
	 */
	protected final ArgsValidator getArgsValidator() {
		return this.argsValidator;
	}
	
	@Override
	public final void validate(final List<String> argList) 
		throws ArgsValidatorException {
		
		this.validateArguments(argList);
		
		if (this.argsValidator != null) {
			
			this.argsValidator.validate(argList);
		}
	}
	
	/**
	 * Validates a {@code List} of arguments.
	 * 
	 * @param argList a {@code List} of arguments to be validated
	 * 
	 * @throws ArgsValidatorException if the arguments are invalid
	 */
	protected abstract void validateArguments(List<String> argList)
		throws ArgsValidatorException;
}
