/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argsvalidator;

import java.util.List;

import org.climax.ArgsValidator;
import org.climax.ArgsValidatorException;

/**
 * An {@code ArgsValidator} implementation that validates for the number of
 * arguments within a valid range.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public final class ArgCountRangeValidator extends AbstractArgsValidator {
	
	/**
	 * Creates a new {@code ArgsValidator} with the provided minimum 
	 * number of arguments, the provided maximum number of arguments, and
	 * the provided {@code ArgsValidator}.
	 * 
	 * @param minArgCount the provided minimum number of arguments
	 * @param maxArgCount the provided maximum number of arguments
	 * @param validator the provided {@code ArgsValidator}
	 * @return a new {@code ArgsValidator}
	 */
	private static ArgsValidator newArgsValidator(
			final int minArgCount, 
			final int maxArgCount, 
			final ArgsValidator validator) {
		
		if (minArgCount > maxArgCount) {
			throw new IllegalArgumentException(
					"minArgCount must be less than or equal to maxArgCount");
		}
		
		return new MinArgCountValidator(
				minArgCount, 
				new MaxArgCountValidator(
						maxArgCount, 
						validator));
	}
	
	/**
	 * Constructs an {@code ArgsCountRangeValidator} with the provided minimum 
	 * number of arguments and the provided maximum number of arguments.
	 * 
	 * @param minArgCount the provided minimum number of arguments
	 * @param maxArgCount the provided maximum number of arguments
	 */
	public ArgCountRangeValidator(
			final int minArgCount, final int maxArgCount) {
		
		this(minArgCount, maxArgCount, null);
	}
	
	/**
	 * Constructs an {@code ArgsCountRangeValidator} with the provided minimum 
	 * number of arguments, the provided maximum number of arguments, and the 
	 * provided {@code ArgsValidator}.
	 * 
	 * @param minArgCount the provided minimum number of arguments
	 * @param maxArgCount the provided maximum number of arguments
	 * @param validator the provided {@code ArgsValidator}
	 */
	public ArgCountRangeValidator(
			final int minArgCount, 
			final int maxArgCount, 
			final ArgsValidator validator) {
		
		super(ArgCountRangeValidator.newArgsValidator(
				minArgCount, maxArgCount, validator));
	}

	@Override
	protected void validateArguments(final List<String> argList)
			throws ArgsValidatorException {
	}

}
