/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argsvalidator;

import java.util.List;

import org.climax.ArgsValidator;
import org.climax.ArgsValidatorException;

/**
 * An {@code ArgsValidator} implementation that validates for the number of 
 * arguments.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
public final class ArgCountValidator extends AbstractArgsValidator {

	/** The valid number of arguments. */
	private final int argumentCount;
	
	/**
	 * Constructs an {@code ArgsCountValidator} with the provided valid 
	 * number of arguments.
	 * 
	 * @param argsCount the provided valid number of arguments 
	 */
	public ArgCountValidator(final int argsCount) {
		this(argsCount, null);
	}
	
	/**
	 * Constructs an {@code ArgsCountValidator} with the provided valid
	 * number of arguments and the provided {@code ArgsValidator}.
	 * 
	 * @param argsCount the provided valid number of arguments
	 * @param validator the provided {@code ArgsValidator}
	 */
	public ArgCountValidator(
			final int argsCount, final ArgsValidator validator) {
		
		super(validator);
		
		if (argsCount < 0) {
			throw new IllegalArgumentException(
					"argsCount must be no less than 0");
		}
		
		this.argumentCount = argsCount;
	}

	@Override
	protected void validateArguments(final List<String> argList)
			throws ArgsValidatorException {

		if (argList.size() != this.argumentCount) {
			
			String message = String.format(
					"only %s specified argument(s) required", 
					this.argumentCount);
			
			throw new ArgsValidatorException(argList, message);			
		}
	}

}
