/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argsvalidator;

import java.util.List;

import org.climax.ArgsValidator;
import org.climax.ArgsValidatorException;

/**
 * An {@code ArgsValidator} implementation that validates for a {@code List} 
 * of zero arguments.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class NoArgsValidator implements ParameterlessArgsValidator {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgsValidatorHolder.ARGS_VALIDATOR}.
	 */
	private static final class ArgsValidatorHolder {

		/** The {@code ArgsValidator}. */
		static final NoArgsValidator ARGS_VALIDATOR =
			new NoArgsValidator();
		
		/**
		 * Constructs an {@code ArgsValidatorHolder}. This constructor is
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgsValidatorHolder() {
		}
	}
	
	/**
	 * Returns a {@code NoArgsValidator}.
	 * 
	 * @return a {@code NoArgsValidator}
	 */	
	public static NoArgsValidator getInstance() {
		return ArgsValidatorHolder.ARGS_VALIDATOR;
	}
	
	/** The {@code ArgsValidator}. */
	private final ArgsValidator argsValidator;	
	
	/**
	 * Constructs a {@code NoArgsValidator}.
	 */
	public NoArgsValidator() {
		
		this.argsValidator = new ArgCountValidator(0, null);
	}

	@Override
	public void validate(final List<String> argList) 
		throws ArgsValidatorException {

		this.argsValidator.validate(argList);
	}

}
