/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argsvalidator;

import java.util.List;

import org.climax.ArgsValidator;
import org.climax.ArgsValidatorException;

/**
 * An {@code ArgsValidator} implementation that does not validate a 
 * {@code List} of arguments.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class PassiveArgsValidator extends AbstractArgsValidator 
	implements ParameterlessArgsValidator {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgsValidatorHolder.ARGS_VALIDATOR}.
	 */
	private static final class ArgsValidatorHolder {

		/** The {@code ArgsValidator}. */
		static final PassiveArgsValidator ARGS_VALIDATOR =
			new PassiveArgsValidator();
		
		/**
		 * Constructs an {@code ArgsValidatorHolder}. This constructor is
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgsValidatorHolder() {
		}
	}
	
	/**
	 * Returns a {@code PassiveArgsValidator}.
	 * 
	 * @return a {@code PassiveArgsValidator}
	 */	
	public static PassiveArgsValidator getInstance() {
		return ArgsValidatorHolder.ARGS_VALIDATOR;
	}

	/**
	 * Constructs a {@code PassiveArgsValidator}.
	 */
	public PassiveArgsValidator() {
		this(null);
	}
	
	/**
	 * Constructs a {@code PassiveArgsValidator} with the provided 
	 * {@code ArgsValidator}.
	 * 
	 * @param validator the provided {@code ArgsValidator}
	 */
	public PassiveArgsValidator(final ArgsValidator validator) {
		super(validator);
	}

	@Override
	protected void validateArguments(final List<String> argList)
			throws ArgsValidatorException {
	}

}
