/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.argsvalidator;

import java.util.List;

import org.climax.ArgsValidator;
import org.climax.ArgsValidatorException;

/**
 * An {@code ArgsValidator} implementation that validates for a {@code List} 
 * of one argument.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class SingleArgValidator extends AbstractArgsValidator 
	implements ParameterlessArgsValidator {

	/**
	 * Lazy initialization holder class idiom for static field for
	 * {@code ArgsValidatorHolder.ARGS_VALIDATOR}.
	 */
	private static final class ArgsValidatorHolder {

		/** The {@code ArgsValidator}. */
		static final SingleArgValidator ARGS_VALIDATOR =
			new SingleArgValidator();
		
		/**
		 * Constructs an {@code ArgsValidatorHolder}. This constructor is
		 * suppressed for noninstantiability outside of this class.
		 */
		private ArgsValidatorHolder() {
		}
	}
	
	/**
	 * Returns a {@code SingleArgValidator}.
	 * 
	 * @return a {@code SingleArgValidator}
	 */	
	public static SingleArgValidator getInstance() {
		return ArgsValidatorHolder.ARGS_VALIDATOR;
	}

	/**
	 * Constructs a {@code SingleArgValidator}.
	 */
	public SingleArgValidator() {
		this(null);
	}
	
	/**
	 * Constructs a {@code SingleArgValidator} with the provided 
	 * {@code ArgsValidator}.
	 * 
	 * @param validator the provided {@code ArgsValidator}
	 */
	public SingleArgValidator(final ArgsValidator validator) {
		
		super(new ArgCountValidator(1, validator));
	}

	@Override
	protected void validateArguments(final List<String> argList)
			throws ArgsValidatorException {
	}

}
