/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import org.climax.ArgAcceptor;
import org.climax.argacceptor.NoArgAcceptor;
import org.climax.argacceptor.ParameterlessArgAcceptor;
import org.climax.argacceptor.SingleArgAcceptor;
import org.climax.argacceptor.UnlimitedArgAcceptor;

/**
 * This class provides utility methods regarding {@code ArgAcceptor}s.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class ArgAcceptors {
	
	/**
	 * Returns the default {@code ArgAcceptor} based on the provided 
	 * {@code TypesType}.
	 * 
	 * @param typesType the provided {@code TypesType}
	 * @return the default {@code ArgAcceptor}
	 */
	static ArgAcceptor getDefault(final TypesType typesType) {
		
		ArgAcceptor argAcceptor = null;
		
		switch (typesType) {
		case ARRAYTYPE:
			argAcceptor = UnlimitedArgAcceptor.getInstance();
			break;
		case LISTTYPE:
			argAcceptor = UnlimitedArgAcceptor.getInstance();
			break;
		case NONE:
			argAcceptor = NoArgAcceptor.getInstance();
			break;
		case TYPE:
			argAcceptor = SingleArgAcceptor.newInstance();
			break;
		case TYPE_ARRAYTYPE:
			argAcceptor = UnlimitedArgAcceptor.getInstance();
			break;
		case TYPE_LISTTYPE:
			argAcceptor = UnlimitedArgAcceptor.getInstance();
			break;
		default:
			throw new AssertionError(String.format(
					"Unknown %1$s: %2$s", 
					TypesType.class.getName(), 
					typesType));
		}
		
		return argAcceptor;
	}
	
	/**
	 * Returns an {@code ArgAcceptor} based on the provided 
	 * {@code ParameterlessArgAcceptor} class.
	 * 
	 * @param argAcceptorClass the provided {@code ParameterlessArgAcceptor} 
	 * class
	 * 
	 * @return an {@code ArgAcceptor}
	 */
	static ArgAcceptor getInstance(
			final Class<? extends ParameterlessArgAcceptor> argAcceptorClass) {
		
		ArgAcceptorClassType argAcceptorClassType = 
				ArgAcceptorClassType.bestDescribes(argAcceptorClass);
		
		if (argAcceptorClassType == null) {
			return Objects.getInstance(argAcceptorClass);
		}
		
		return argAcceptorClassType.getArgAcceptor();
	}
	
	/**
	 * Constructs an instance of {@code ArgAcceptors}. This 
	 * constructor is suppressed for noninstantiability outside of this 
	 * class.
	 */
	private ArgAcceptors() {
	}

}
