/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.climax.argacceptor.ParameterlessArgAcceptor;
import org.climax.argparser.ParameterlessArgParser;
import org.climax.argsvalidator.ParameterlessArgsValidator;


/**
 * Provides further specification of the {@code ArgGroupComplete}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 * 
 * @see ArgGroupCompleteReturnTypeMethod
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
public @interface ArgGroupCompleteSpec {

	/**
	 * The {@code ArgAcceptor} class.
	 */
	Class<? extends ParameterlessArgAcceptor> argAcceptorClass() 
		default DummyArgAcceptor.class;
	
	/**
	 * The {@code ArgParser} class.
	 */
	Class<? extends ParameterlessArgParser<? extends Object>> argParserClass() 
		default DummyArgParser.class;
	
	/**
	 * The {@code ArgsValidator} class.
	 */
	Class<? extends ParameterlessArgsValidator> argsValidatorClass() 
		default DummyArgsValidator.class;
	
	/**
	 * The argument type.
	 */
	String argumentType() default "";
	
	/**
	 * The default argument format strings.
	 * <p>
	 * The property keys that can be applied as expandable properties  
	 * within the provided format strings are found in the 
	 * {@link org.climax.ArgGroupBuilder#defaultArguments(java.util.List)} 
	 * method.
	 * </p> 
	 */
	String[] defaultArguments() default { };
	
	/**
	 * The boolean value to indicate if the {@code ArgGroupDoc} is excluded 
	 * from documentation.
	 */
	boolean hidden() default false;
	
	/**
	 * The ordinal of the {@code ArgGroup} in relation to other 
	 * {@code ArgGroup}s.
	 */
	int ordinal() default 0;
	
	/**
	 * The format string for the syntax for the {@code ArgGroup}.
	 * <p>
	 * The property keys that can be applied as expandable properties  
	 * within the provided format string are found in the 
	 * {@link org.climax.ArgGroupDocBuilder#syntax(String)} method.
	 * </p> 
	 */
	String syntax() default "";
	
	/**
	 * The boolean value to indicate if the {@code ArgGroup} is excluded 
	 * from parsing.
	 */
	boolean unused() default false;	
}
