/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import org.climax.ArgParser;
import org.climax.argparser.BigDecimalArgParser;
import org.climax.argparser.BigIntegerArgParser;
import org.climax.argparser.BooleanArgParser;
import org.climax.argparser.ByteArgParser;
import org.climax.argparser.CharacterArgParser;
import org.climax.argparser.ClassArgParser;
import org.climax.argparser.DateArgParser;
import org.climax.argparser.DoubleArgParser;
import org.climax.argparser.FileArgParser;
import org.climax.argparser.FileInputStreamArgParser;
import org.climax.argparser.FileOutputStreamArgParser;
import org.climax.argparser.FileReaderArgParser;
import org.climax.argparser.FileWriterArgParser;
import org.climax.argparser.FloatArgParser;
import org.climax.argparser.IntegerArgParser;
import org.climax.argparser.LongArgParser;
import org.climax.argparser.ShortArgParser;
import org.climax.argparser.StringArgParser;
import org.climax.argparser.VoidArgParser;

/**
 * An {@code ArgParser} class type. The constants of this 
 * enumerated type provides a classification of {@code ArgParser} 
 * classes.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
enum ArgParserClassType {

	/** {@code BigDecimalArgParser} class. */
	BIG_DECIMAL_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return BigDecimalArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return BigDecimalArgParser.getInstance();
		}
	},
	
	/** {@code BigIntegerArgParser} class. */
	BIG_INTEGER_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return BigIntegerArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return BigIntegerArgParser.getInstance();
		}
	},
	
	/** {@code BooleanArgParser} class. */
	BOOLEAN_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return BooleanArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return BooleanArgParser.getInstance();
		}
	},
	
	/** {@code ByteArgParser} class. */
	BYTE_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return ByteArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return ByteArgParser.getInstance();
		}
	},
	
	/** {@code CharacterArgParser} class. */
	CHARACTER_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return CharacterArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return CharacterArgParser.getInstance();
		}
	},
	
	/** {@code ClassArgParser} class. */
	CLASS_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return ClassArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return ClassArgParser.getInstance();
		}
	},
	
	/** {@code DateArgParser} class. */
	DATE_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return DateArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return DateArgParser.getInstance();
		}
	},
	
	/** {@code DoubleArgParser} class. */
	DOUBLE_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return DoubleArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return DoubleArgParser.getInstance();
		}
	},
	
	/** {@code DummyArgParser} class. */
	DUMMY_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return DummyArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return null;
		}
	},
	
	/** {@code FileArgParser} class. */
	FILE_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return FileArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return FileArgParser.getInstance();
		}
	},
	
	/** {@code FileInputStreamArgParser} class. */
	FILE_INPUT_STREAM_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return FileInputStreamArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return FileInputStreamArgParser.getInstance();
		}
	},
	
	/** {@code FileOutputStreamArgParser} class. */
	FILE_OUTPUT_STREAM_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return FileOutputStreamArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return FileOutputStreamArgParser.getInstance();
		}
	},
	
	/** {@code FileReaderArgParser} class. */
	FILE_READER_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return FileReaderArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return FileReaderArgParser.getInstance();
		}
	},
	
	/** {@code FileWriteArgParser} class. */
	FILE_WRITER_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return FileWriterArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return FileWriterArgParser.getInstance();
		}
	},
	
	/** {@code FloatArgParser} class. */
	FLOAT_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return FloatArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return FloatArgParser.getInstance();
		}
	},
	
	/** {@code IntegerArgParser} class. */
	INTEGER_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return IntegerArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return IntegerArgParser.getInstance();
		}
	},
	
	/** {@code LongArgParser} class. */
	LONG_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return LongArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return LongArgParser.getInstance();
		}
	},
	
	/** {@code ShortArgParser} class. */
	SHORT_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return ShortArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return ShortArgParser.getInstance();
		}
	},
	
	/** {@code StringArgParser} class. */
	STRING_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return StringArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return StringArgParser.getInstance();
		}
	},
	
	/** {@code VoidArgParser} class. */
	VOID_ARG_PARSER {
		@Override
		boolean describes(final Class<? extends ArgParser<?>> argParserClass) {
			return VoidArgParser.class == argParserClass;
		}

		@Override
		ArgParser<? extends Object> getArgParser() {
			return VoidArgParser.getInstance();
		}
	};
	
	/**
	 * Returns the enum constant that describes the type of 
	 * {@code ArgParser} class from the provided {@code ArgParser} 
	 * class.
	 *   
	 * @param argParserClass the provided {@code ArgParser} class
	 * 
	 * @return an enum constant that describes the type of 
	 * {@code ArgParser} class from the provided {@code ArgParser} 
	 * class or {@code null} if there is no enum constant that 
	 * describes the type of {@code ArgParser} class from the provided 
	 * {@code ArgParser} class
	 */
	static ArgParserClassType bestDescribes(
			final Class<? extends ArgParser<?>> argParserClass) {
		
		for (ArgParserClassType argParserClassType 
				: ArgParserClassType.values()) {
			
			if (argParserClassType.describes(argParserClass)) {
				
				return argParserClassType;
			}
		}
		
		return null;
	}
	
	/**
	 * Indicates if the provided {@code ArgParser} class is described by
	 * this {@code ArgParserClassType}.
	 * 
	 * @param argParserClass the provided {@code ArgParser} class
	 * 
	 * @return {@code true} if the provided {@code ArgParser} class is 
	 * described by this {@code ArgParserClassType}
	 */
	abstract boolean describes(
			final Class<? extends ArgParser<?>> argParserClass);
	
	/**
	 * Returns an {@code ArgParser} based on this {@code ArgParserClassType}.
	 * 
	 * @return an {@code ArgParser}
	 */
	abstract ArgParser<? extends Object> getArgParser();
}
