/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

/**
 * An {@code InvocationHandler} implementation that forwards the arguments to 
 * another {@code InvocationHandler} associated with the {@code Method} that 
 * was invoked.
 *  
 * @author Climax Development (climax.development@gmail.com)
 */
final class ForwardingInvocationHandler implements InvocationHandler {

	/**
	 * The {@code Map} that maps {@code Method}s and their associated 
	 * {@code InvocationHandler}s.
	 */
	private final Map<Method, InvocationHandler> methodMap;
	
	/**
	 * Constructs a {@code ForwardingInvocationHandler} with the provided
	 * {@code Map} that maps {@code Method}s and their associated 
	 * {@code InvocationHandler}s.
	 * 
	 * @param map the provided {@code Map} that maps {@code Method}s and 
	 * their associated {@code InvocationHandler}s
	 */
	public ForwardingInvocationHandler(
			final Map<Method, InvocationHandler> map) {
		
		this.methodMap = new HashMap<Method, InvocationHandler>();
		
		this.methodMap.putAll(map);
	}
	
	@Override
	public Object invoke(
			final Object proxy, final Method method, final Object[] args)
			throws Throwable {
		
		Object returnValue = null;
		
		if (this.methodMap.containsKey(method)) {
			
			InvocationHandler handler =	this.methodMap.get(method);
			
			returnValue = handler.invoke(proxy, method, args);
		}
		
		return returnValue;
	}
}