/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

/**
 * Thrown when a {@code Class} is invalid.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class InvalidClassException extends RuntimeException {

	/** The default serial version UID. */
	private static final long serialVersionUID = 1L;

	/** The invalid {@code Class}. */
	private Class<?> cls;
	
	/**
	 * Constructs an {@code InvalidClassException} with the provided 
	 * {@code Class} and the specified detail message.
	 * 
	 * @param c the provided {@code Class}
	 * @param message the specified detail message.
	 */	
	InvalidClassException(final Class<?> c, final String message) {
		super(String.format("%1$s : %2$s", c, message));
		this.cls = c;
	}
	
	/**
	 * Returns the invalid {@code Class}.
	 * 
	 * @return the invalid {@code Class}
	 */
	public Class<?> getInvalidClass() {
		return this.cls;
	}
}
