/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import java.lang.reflect.Method;

/**
 * Thrown when a {@code Method} is invalid.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public final class InvalidMethodException extends RuntimeException {

	/** The default serial version UID. */
	private static final long serialVersionUID = 1L;

	/** The invalid {@code Method}. */
	private transient Method method;

	/**
	 * Constructs an {@code InvalidMethodException} with the provided 
	 * {@code Method} and the specified detail message.
	 * 
	 * @param m the provided {@code Method}
	 * @param message the specified detail message.
	 */	
	InvalidMethodException(final Method m, final String message) {
		
		super(String.format(
				"Method '%1$s' : %2$s", 
				m.toGenericString(), 
				message));
		
		this.method = m;
	}

	/**
	 * Returns the invalid {@code Method}.
	 * 
	 * @return the invalid {@code Method}
	 */	
	public Method getInvalidMethod() {
		return this.method;
	}
}
