/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;

/**
 * An {@code InvocationHandler} implementation that invokes methods of the 
 * provided {@code Object}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
final class ObjectInvocationHandler implements InvocationHandler {

	/** The {@code Object}. */
	private final Object object;
	
	/**
	 * Constructs an {@code ObjectInvocationHandler} with the provided 
	 * {@code Object}.
	 * 
	 * @param obj the provided {@code Object}
	 */
	ObjectInvocationHandler(final Object obj) {
		
		if (obj == null) {
			throw new NullPointerException("object must not be null");
		}
		
		this.object = obj;
	}
	
	@Override
	public Object invoke(
			final Object proxy,	final Method method, final Object[] args) 
			throws Throwable {
		
		return method.invoke(this.object, args);
	}

}
