/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.climax.OptionType;

/**
 * Provides further specification of the {@code OptionComplete}.
 *  
 * @author Climax Development (climax.development@gmail.com)
 * 
 * @see OptionGroupCompleteSpec
 */
@Retention(RetentionPolicy.RUNTIME)
@Target({ })
public @interface OptionCompleteSpec {

	/**
	 * The boolean value to indicate if the {@code OptionDoc} is excluded 
	 * from documentation.
	 */
	boolean hidden() default false;
	
	/**
	 * The name of the {@code Option}.
	 */
	String name() default "";
	
	/**
	 * The {@code OptionType}.
	 */
	OptionType optionType() default OptionType.GNU_LONG;
	
	/**
	 * The ordinal of the {@code OptionDoc} in relation to other 
	 * {@code OptionDoc}s.
	 */
	int ordinal() default 0;
	
	/**
	 * The boolean value to indicate if the {@code Option} is excluded from 
	 * parsing.
	 */
	boolean unused() default false;
	
	/**
	 * The format string for the usage of the {@code Option}.
	 * <p>
	 * The property keys that can be applied as expandable properties  
	 * within the provided format string are found in the 
	 * {@link org.climax.OptionDocBuilder#usage(String)} method.
	 * </p> 
	 */
	String usage() default "";
}
