/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax.reflect;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Provides further specification of the {@code OptionsComplete}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 * 
 * @see OptionsCompleteInterface
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface OptionsCompleteSpec {
	
	/** 
	 * The format string for the help information for the {@code Options}.
	 * <p>
	 * The property keys that can be applied as expandable properties 
	 * within the provided format string are found in the 
	 * {@link org.climax.OptionsDoc#setHelp(String)} method. 
	 * </p> 
	 */	
	String help() default "";
	
	/**
	 * The format string for the usage of the {@code Options}.
	 * <p>
	 * The property keys that can be applied as expandable properties 
	 * within the provided format string are found in the 
	 * {@link org.climax.OptionsDoc#setUsage(String)} method.
	 * </p>
	 */	
	String usage() default "";
}
