/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import static org.junit.Assert.assertEquals;

import java.util.Map;

import org.junit.Test;

/**
 * JUnit Test Case for {@code OptionTypeDoc}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public class OptionTypeDocTest {

	/**
	 * Test method for {@link org.climax.OptionTypeDoc#getOptionType()}.
	 */
	@Test
	public final void testGetOptionType01() {
		assertEquals(
				OptionType.POSIX, 
				OptionTypeDoc.POSIX.getOptionType());
	}

	/**
	 * Test method for {@link org.climax.OptionTypeDoc#getOptionType()}.
	 */
	@Test
	public final void testGetOptionType02() {
		assertEquals(
				OptionType.GNU_SHORT_LONG,
				OptionTypeDoc.GNU_SHORT_LONG.getOptionType());
	}

	/**
	 * Test method for {@link org.climax.OptionTypeDoc#getOptionType()}.
	 */
	@Test
	public final void testGetOptionType03() {
		assertEquals(
				OptionType.GNU_LONG,
				OptionTypeDoc.GNU_LONG.getOptionType());
	}

	/**
	 * Test method for {@link 
	 * org.climax.OptionTypeDoc#getOptionTypeDocsProperties()}.
	 */
	@Test
	public final void testGetOptionTypeDocsProperties() {
		
		Map<String, String> m = OptionTypeDoc.getOptionTypeDocsProperties();
		
		assertEquals(
				"",
				m.get(OptionType.POSIX + "." 
				+ OptionTypeDocPropertyKeys.ASSIGNMENT_OPERATOR));
		assertEquals(
				"-",
				m.get(OptionType.POSIX + "." 
				+ OptionTypeDocPropertyKeys.DELIMITER));
		
		assertEquals(
				" ",
				m.get(OptionType.GNU_SHORT_LONG + "." 
				+ OptionTypeDocPropertyKeys.ASSIGNMENT_OPERATOR));
		assertEquals(
				"-",
				m.get(OptionType.GNU_SHORT_LONG + "." 
				+ OptionTypeDocPropertyKeys.DELIMITER));
		
		assertEquals(
				"=",
				m.get(OptionType.GNU_LONG + "." 
				+ OptionTypeDocPropertyKeys.ASSIGNMENT_OPERATOR));
		assertEquals(
				"--",
				m.get(OptionType.GNU_LONG + "." 
				+ OptionTypeDocPropertyKeys.DELIMITER));		
	}

	/**
	 * Test method for {@link org.climax.OptionTypeDoc#getProperties()}.
	 */
	@Test
	public final void testGetProperties01() {
		Map<String, String> m = OptionTypeDoc.POSIX.getProperties();
		assertEquals(
				"",
				m.get(OptionTypeDocPropertyKeys.ASSIGNMENT_OPERATOR));
		assertEquals(
				"-",
				m.get(OptionTypeDocPropertyKeys.DELIMITER));
	}

	/**
	 * Test method for {@link org.climax.OptionTypeDoc#getProperties()}.
	 */
	@Test
	public final void testGetProperties02() {
		Map<String, String> m = OptionTypeDoc.GNU_SHORT_LONG.getProperties();
		assertEquals(
				" ",
				m.get(OptionTypeDocPropertyKeys.ASSIGNMENT_OPERATOR));
		assertEquals(
				"-",
				m.get(OptionTypeDocPropertyKeys.DELIMITER));
	}

	/**
	 * Test method for {@link org.climax.OptionTypeDoc#getProperties()}.
	 */
	@Test
	public final void testGetProperties03() {
		Map<String, String> m = OptionTypeDoc.GNU_LONG.getProperties();
		assertEquals(
				"=",
				m.get(OptionTypeDocPropertyKeys.ASSIGNMENT_OPERATOR));
		assertEquals(
				"--",
				m.get(OptionTypeDocPropertyKeys.DELIMITER));
	}

	/**
	 * Test method for {@link 
	 * org.climax.OptionTypeDoc#of(org.climax.OptionType)}.
	 */
	@Test
	public final void testOf01() {
		assertEquals(
				OptionTypeDoc.POSIX, 
				OptionTypeDoc.of(OptionType.POSIX));
	}

	/**
	 * Test method for {@link 
	 * org.climax.OptionTypeDoc#of(org.climax.OptionType)}.
	 */
	@Test
	public final void testOf02() {
		assertEquals(
				OptionTypeDoc.GNU_SHORT_LONG, 
				OptionTypeDoc.of(OptionType.GNU_SHORT_LONG));
	}

	/**
	 * Test method for {@link 
	 * org.climax.OptionTypeDoc#of(org.climax.OptionType)}.
	 */
	@Test
	public final void testOf03() {
		assertEquals(
				OptionTypeDoc.GNU_LONG,
				OptionTypeDoc.of(OptionType.GNU_LONG));
	}

}
