/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import static org.junit.Assert.assertEquals;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * JUnit Test Case for {@code PackageDocImpl}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public class PackageDocImplTest {

	/** */
	private List<Package> packageList;
	
	/** */
	@Before
	public final void setUp() {
		this.packageList = Arrays.asList(Package.getPackages());
		PackageDocImpl.setPackages(this.packageList);
	}
	
	/** */
	@After
	public final void tearDown() {
		this.packageList = null;
	}
	
	/**
	 * Test method for {@link org.climax.PackageDocImpl#getPackage()}.
	 */
	@Test
	public final void testGetPackage() {
		
		for (Package pkg : this.packageList) {
			
			PackageDocImpl packageDocImpl = PackageDocImpl.of(pkg);
			
			assertEquals(pkg, packageDocImpl.getPackage());
		}
	}

	/**
	 * Test method for {@link org.climax.PackageDocImpl#getPackageDocImpls()}.
	 */
	@Test
	public final void testGetPackageDocImpls() {
		
		assertEquals(
				PackageDocImpl.getPackageDocImpls(), 
				PackageDocImpl.getPackageDocImpls());
	}

	/**
	 * Test method for {@link 
	 * org.climax.PackageDocImpl#getPackageDocImplsProperties()}.
	 */
	@Test
	public final void testGetPackageDocImplsProperties() {
		
		Map<String, String> packageDocImplsProperties = 
				PackageDocImpl.getPackageDocImplsProperties();
		
		for (Package pkg : this.packageList) {
			
			String implTitle = pkg.getImplementationTitle();
			String implVendor = pkg.getImplementationVendor();
			String implVersion = pkg.getImplementationVersion();
			String specTitle = pkg.getSpecificationTitle();
			String specVendor = pkg.getSpecificationVendor();
			String specVersion = pkg.getSpecificationVersion();
			
			assertEquals(
					implTitle, 
					packageDocImplsProperties.get(
							pkg.getName() 
							+ "." + PackageDocPropertyKeys.IMPL_TITLE));
			
			assertEquals(
					implVendor,
					packageDocImplsProperties.get(
							pkg.getName() 
							+ "." + PackageDocPropertyKeys.IMPL_VENDOR));
			
			assertEquals(
					implVersion,
					packageDocImplsProperties.get(
							pkg.getName() 
							+ "." + PackageDocPropertyKeys.IMPL_VERSION));
			
			assertEquals(
					specTitle,
					packageDocImplsProperties.get(
							pkg.getName() 
							+ "." + PackageDocPropertyKeys.SPEC_TITLE));
			
			assertEquals(
					specVendor,
					packageDocImplsProperties.get(
							pkg.getName() 
							+ "." + PackageDocPropertyKeys.SPEC_VENDOR));
			
			assertEquals(
					specVersion, 
					packageDocImplsProperties.get(
							pkg.getName() 
							+ "." + PackageDocPropertyKeys.SPEC_VERSION));
		}
	}

	/**
	 * Test method for {@link org.climax.PackageDocImpl#getPackages()}.
	 */
	@Test
	public final void testGetPackages() {
		
		assertEquals(
				PackageDocImpl.getPackages(), 
				PackageDocImpl.getPackages());
	}
	
	/**
	 * Test method for {@link org.climax.PackageDocImpl#getProperties()}.
	 */
	@Test
	public final void testGetProperties() {
		
		for (Package pkg : this.packageList) {
			
			String implTitle = pkg.getImplementationTitle();
			String implVendor = pkg.getImplementationVendor();
			String implVersion = pkg.getImplementationVersion();
			String specTitle = pkg.getSpecificationTitle();
			String specVendor = pkg.getSpecificationVendor();
			String specVersion = pkg.getSpecificationVersion();
			
			PackageDocImpl packageDocImpl = PackageDocImpl.of(pkg);
			
			Map<String, String> properties = packageDocImpl.getProperties();
			
			assertEquals(
					implTitle, 
					properties.get(PackageDocPropertyKeys.IMPL_TITLE));
			
			assertEquals(
					implVendor,
					properties.get(PackageDocPropertyKeys.IMPL_VENDOR));
			
			assertEquals(
					implVersion,
					properties.get(PackageDocPropertyKeys.IMPL_VERSION));
			
			assertEquals(
					specTitle,
					properties.get(PackageDocPropertyKeys.SPEC_TITLE));
			
			assertEquals(
					specVendor,
					properties.get(PackageDocPropertyKeys.SPEC_VENDOR));
			
			assertEquals(
					specVersion,
					properties.get(PackageDocPropertyKeys.SPEC_VERSION));
		}
	}
	
	/**
	 * Test method for {@link org.climax.PackageDocImpl#of(java.lang.Package)}.
	 */
	@Test
	public final void testOf() {
		
		for (Package pkg : this.packageList) {
			
			assertEquals(PackageDocImpl.of(pkg), PackageDocImpl.of(pkg));
		}
	}

	/**
	 * Test method for {@link org.climax.PackageDocImpl#setPackages()}.
	 */
	@Test
	public final void testSetPackages() {
		
		this.packageList = Arrays.asList(new Package[] { });
		
		PackageDocImpl.setPackages(this.packageList);
		
		assertEquals(this.packageList, PackageDocImpl.getPackages());
	}

}
