/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import static org.junit.Assert.assertEquals;

import java.util.AbstractMap;
import java.util.Map;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * JUnit Test Case for {@code Properties.Property}. 
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public class PropertiesPropertyTest {
	
	/** */
	private Properties.Property property1;
	
	/** */
	private Properties.Property property2;
	
	/** */
	private Properties.Property property3;
	
	/** */
	@Before
	public final void setUp() {
		this.property1 = new Properties.Property("foo", "bar");
		this.property2 = new Properties.Property("foo");
		this.property3 = new Properties.Property("bar");
	}
	
	/** */
	@After
	public final void tearDown() {
		this.property1 = null;
		this.property2 = null;
		this.property3 = null;
	}

	/**
	 * Test method for {@link org.climax.Properties.Property#getKey()}.
	 */
	@Test
	public final void testGetKey1() {
		
		assertEquals("foo", this.property1.getKey());
	}

	/**
	 * Test method for {@link org.climax.Properties.Property#getKey()}.
	 */
	@Test
	public final void testGetKey2() {
		
		assertEquals("foo", this.property2.getKey());
	}

	/**
	 * Test method for {@link org.climax.Properties.Property#getKey()}.
	 */
	@Test
	public final void testGetKey3() {
		
		assertEquals("bar", this.property3.getKey());
	}

	/**
	 * Test method for {@link org.climax.Properties.Property#getValue()}.
	 */
	@Test
	public final void testGetValue1() {
		
		assertEquals("bar", this.property1.getValue());
	}
	
	/**
	 * Test method for {@link org.climax.Properties.Property#getValue()}.
	 */
	@Test
	public final void testGetValue2() {
		
		assertEquals("", this.property2.getValue());
	}
	
	/**
	 * Test method for {@link org.climax.Properties.Property#getValue()}.
	 */
	@Test
	public final void testGetValue3() {
		
		assertEquals("", this.property3.getValue());
	}

	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#Property(java.util.Map.Entry)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testPropertyEntryOfQextendsStringQextendsStringForNullPointerException1() {
		
		Map.Entry<String, String> e = null;
		
		new Properties.Property(e);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#Property(java.util.Map.Entry)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testPropertyEntryOfQextendsStringQextendsStringForNullPointerException2() {
		
		Map.Entry<String, String> e = 
			new AbstractMap.SimpleEntry<String, String>(null, "");
		
		new Properties.Property(e);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#Property(java.util.Map.Entry)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testPropertyEntryOfQextendsStringQextendsStringForNullPointerException3() {
		
		Map.Entry<String, String> e = 
			new AbstractMap.SimpleEntry<String, String>("bar", null);
		
		new Properties.Property(e);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#Property(java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPropertyStringForNullPointerException() {
		
		String s = null;
		
		new Properties.Property(s);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#Property(java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPropertyStringStringForNullPointerException1() {
		
		new Properties.Property(null, "");
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#Property(java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPropertyStringStringForNullPointerException2() {
		
		new Properties.Property("bar", null);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#setValue(java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testSetValueForNullPointerException() {
		
		this.property1.setValue(null);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#setValue(java.lang.String)}.
	 */	
	@Test
	public final void testSetValueForReturnValue1() {
		
		assertEquals("bar", this.property1.setValue("baz"));
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#setValue(java.lang.String)}.
	 */	
	@Test
	public final void testSetValueForReturnValue2() {
		
		assertEquals("", this.property2.setValue("baz"));
	}
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#setValue(java.lang.String)}.
	 */	
	@Test
	public final void testSetValueForReturnValue3() {
		
		assertEquals("", this.property3.setValue("baz"));
	}

	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#toExpandableString()}.
	 */
	@Test
	public final void testToExpandableString1() {
		assertEquals("${foo}", this.property1.toExpandableString());
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#toExpandableString()}.
	 */
	@Test
	public final void testToExpandableString2() {
		assertEquals("${foo}", this.property2.toExpandableString());
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Properties.Property#toExpandableString()}.
	 */
	@Test
	public final void testToExpandableString3() {
		assertEquals("${bar}", this.property3.toExpandableString());
	}

}
