/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

import java.util.HashMap;
import java.util.Map;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * JUnit Test Case for {@code Properties}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public class PropertiesTest {
	
	/** */
	private Properties properties1;
	
	/** */
	private Properties properties2;
	
	/** */
	private Properties properties3;
	
	/** */
	@Before
	public final void setUp() {
		this.properties1 = new Properties();
		this.properties1.put("foo", "bar");
		this.properties2 = new Properties();
		this.properties2.put("greeting", "hello");
		this.properties2.put("valediction", "goodbye");
		this.properties3 = new Properties();
		this.properties3.put("one", "1");
		this.properties3.put("two", "2");
		this.properties3.put("three", "3");
	}

	/** */
	@After
	public final void tearDown() {
		this.properties1 = null;
		this.properties2 = null;
		this.properties3 = null;
	}

	/**
	 * Test method for {@link org.climax.Properties#Properties(java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testPropertiesMapOfQextendsStringQextendsStringForNullPointerException1() {
		
		new Properties(null);
	}

	/**
	 * Test method for {@link org.climax.Properties#Properties(java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testPropertiesMapOfQextendsStringQextendsStringForNullPointerException2() {
		
		Map<String, String> m = new HashMap<String, String>();
		m.put(null, "");
		
		new Properties(m);
	}

	/**
	 * Test method for {@link org.climax.Properties#Properties(java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testPropertiesMapOfQextendsStringQextendsStringForNullPointerException3() {
		
		Map<String, String> m = new HashMap<String, String>();
		m.put("bar", null);
		
		new Properties(m);
	}

	/**
	 * Test method for {@link org.climax.Properties#putAll(java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPutAllForNullPointerException1() {
		
		this.properties1.putAll(null);
	}

	/**
	 * Test method for {@link org.climax.Properties#putAll(java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPutAllForNullPointerException2() {
		
		Map<String, String> m = new HashMap<String, String>();
		m.put(null, "");

		this.properties1.putAll(m);
	}

	/**
	 * Test method for {@link org.climax.Properties#putAll(java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPutAllForNullPointerException3() {
		
		Map<String, String> m = new HashMap<String, String>();
		m.put("baz", null);

		this.properties1.putAll(m);
	}

	/**
	 * Test method for {@link 
	 * org.climax.Properties#put(java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPutForNullPointerException1() {
		
		this.properties1.put(null, "");
	}

	/**
	 * Test method for {@link 
	 * org.climax.Properties#put(java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testPutForNullPointerException2() {
		
		this.properties1.put("baz", null);
	}

	/**
	 * Test method for {@link 
	 * org.climax.Properties#put(java.lang.String, java.lang.String)}.
	 */
	@Test
	public final void testPutForReturnValue1() {
		
		assertNull(this.properties1.put("baz", ""));
	}

	/**
	 * Test method for {@link 
	 * org.climax.Properties#put(java.lang.String, java.lang.String)}.
	 */
	@Test
	public final void testPutForReturnValue2() {
		
		assertEquals("hello", this.properties2.put("greeting", "hi"));
	}

	/**
	 * Test method for {@link 
	 * org.climax.Properties#put(java.lang.String, java.lang.String)}.
	 */
	@Test
	public final void testPutForReturnValue3() {
		
		assertNull(this.properties3.put("zero", "0"));
	}

}
