/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import static org.junit.Assert.assertEquals;

import java.util.HashMap;
import java.util.Map;

import org.junit.Test;

/**
 * JUnit Test Case for {@code StringExpander}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public class StringExpanderTest {

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test
	public final void testExpand1() {
		
		String string = "${foo}";
		
		Map<String, String> map = new HashMap<String, String>();
		map.put("foo", "bar");
		
		String expected = "bar";
		
		assertEquals(expected, StringExpander.expand(string, map));
	}

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test
	public final void testExpand2() {
		
		String string = "I don't know why you say ${valediction} and I say " 
				+ "${greeting}.";
		
		Map<String, String> map = new HashMap<String, String>();
		map.put("greeting", "hello");
		map.put("valediction", "goodbye");
		
		String expected = "I don't know why you say goodbye and I say hello.";
		
		assertEquals(expected, StringExpander.expand(string, map));
	}

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test
	public final void testExpand3() {
		
		String string = "$${one}=${one},$${two}=${two},$${three}=${three}";
		
		Map<String, String> map = new HashMap<String, String>();
		map.put("one", "1");
		map.put("two", "2");
		map.put("three", "3");
		
		String expected = "${one}=1,${two}=2,${three}=3";
		
		assertEquals(expected, StringExpander.expand(string, map));
	}

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test
	public final void testExpand4() {
		
		String string = "} { ${$${key1${key2}${key3${key1}}$}} { }";
		
		Map<String, String> map = new HashMap<String, String>();
		map.put("key1", "1");
		map.put("key2", "2");
		map.put("key31", "31");
		map.put("${key1231}", "1231");
		
		String expected = "} { 1231 { }";
		
		assertEquals(expected, StringExpander.expand(string, map));
	}

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test
	public final void testExpand5() {
		
		String string = "";
		
		Map<String, String> map = new HashMap<String, String>();
		
		String expected = "";
		
		assertEquals(expected, StringExpander.expand(string, map));
	}

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test
	public final void testExpand6() {
		
		String string = "${bogus}";
		
		Map<String, String> map = new HashMap<String, String>();
		
		String expected = "${bogus}";
		
		assertEquals(expected, StringExpander.expand(string, map));
	}

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test
	public final void testExpand7() {
		
		String string = "${}";
		
		Map<String, String> map = new HashMap<String, String>();
		
		String expected = "${}";
		
		assertEquals(expected, StringExpander.expand(string, map));
	}

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testExpandForNullPointerException1() {
		
		String string = null;
		
		Map<String, String> map = new HashMap<String, String>();
		
		StringExpander.expand(string, map);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testExpandForNullPointerException2() {
		
		String string = "";
		
		Map<String, String> map = null;
		
		StringExpander.expand(string, map);
	}	

	/**
	 * Test method for {@link 
	 * org.climax.StringExpander#expand(java.lang.String, java.util.Map)}.
	 */
	@Test(expected = StringExpansionException.class)
	public final void testExpandForStringExpansionException() {
		
		String string = " ${foo ";
		
		Map<String, String> map = new HashMap<String, String>();
		map.put("foo", "bar");
		
		StringExpander.expand(string, map);
	}	

}
