/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

/**
 * JUnit Test Case for {@code Strings}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public class StringsTest {

	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String)}.
	 */
	@Test
	public final void testConcatStringString() {
		
		String s1 = "can";
		
		String s2 = "not";
		
		assertEquals(
				"Strings 1 and 2 are not concatenated.",
				"cannot",
				Strings.concat(s1, s2));
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)	
	public final void testConcatStringStringForNullPointerException1() {
		
		Strings.concat(null, "not");
	}

	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)	
	public final void testConcatStringStringForNullPointerException2() {
		
		Strings.concat("can", null);
	}
	
	
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String)}.
	 */
	@Test
	public final void testConcatStringStringString() {
		
		String s1 = "to";
		
		String s2 = "get";
		
		String s3 = "her";
		
		assertEquals(
				"Strings 1, 2, and 3 are not concatenated.",
				"together",
				Strings.concat(s1, s2, s3));		
	}

	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testConcatStringStringStringForNullPointerException1() {
		
		Strings.concat(null, "get", "her");
	}
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testConcatStringStringStringForNullPointerException2() {
		
		Strings.concat("to", null, "her");
	}
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String)}.
	 */
	@Test(expected = NullPointerException.class)
	public final void testConcatStringStringStringForNullPointerException3() {
		
		Strings.concat("to", "get", null);
	}
	
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String, java.lang.String[])}.
	 */
	@Test
	public final void testConcatStringStringStringStringArray() {
		
		String s1 = "File";
		
		String s2 = "Not";
		
		String s3 = "Found";
		
		String s4 = "Exception";
		
		assertEquals(
				"String 1, 2, 3, and 4 are not concatenated.",
				"FileNotFoundException",
				Strings.concat(s1, s2, s3, s4));
	}

	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String, java.lang.String[])}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testConcatStringStringStringStringArrayForNullPointerException1() {
	
		Strings.concat(null, "Not", "Found", "Exception");
	}
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String, java.lang.String[])}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testConcatStringStringStringStringArrayForNullPointerException2() {
	
		Strings.concat("File", null, "Found", "Exception");
	}
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String, java.lang.String[])}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testConcatStringStringStringStringArrayForNullPointerException3() {
	
		Strings.concat("File", "Not", null, "Exception");
	}
	/**
	 * Test method for {@link 
	 * org.climax.Strings#concat(java.lang.String, java.lang.String, java.lang.String, java.lang.String[])}.
	 */
	@Test(expected = NullPointerException.class)
	public final void 
	testConcatStringStringStringStringArrayForNullPointerException4() {
	
		Strings.concat("File", "Not", "Found", new String[] {null});
	}
	
}
