/*
 * Climax - A Java command line argument parser framework
 * Copyright (c) 2010-2013 Climax contributors
 * See the file LICENSE.txt for copying permission.
 */

package org.climax;

import static org.junit.Assert.assertEquals;

import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

import org.junit.Test;

/**
 * JUnit Test Case for {@code UtilImpl}.
 * 
 * @author Climax Development (climax.development@gmail.com)
 */
public class UtilTest {

	/**
	 * Test method for {@link org.climax.Util#expand1(String, java.util.Map)}.
	 */
	@Test
	public final void testExpand1() {
		
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.append(
				"$${one}=${one},$${two}=${two},$${three}=${three}\n");
		stringBuilder.append("Operating System: ${os.name}\n");
		stringBuilder.append("java.lang implementation version: ").append(
				"${java.lang.implVersion}\n");
		stringBuilder.append("GNU long option assignment operator: ").append(
				"${GNU_LONG.assignmentOperator}\n");

		Map<String, String> map = new HashMap<String, String>();
		map.put("one", "1");
		map.put("two", "2");
		map.put("three", "3");
		
		StringBuilder expectedBuilder = new StringBuilder();
		expectedBuilder.append("${one}=1,${two}=2,${three}=3\n");
		expectedBuilder.append("Operating System: ${os.name}\n");
		expectedBuilder.append("java.lang implementation version: ").append(
				"${java.lang.implVersion}\n");
		expectedBuilder.append("GNU long option assignment operator: ").append(
				"${GNU_LONG.assignmentOperator}\n");
		
		assertEquals(
				expectedBuilder.toString(), 
				Util.expand1(stringBuilder.toString(), map));
	}

	/**
	 * Test method for {@link org.climax.Util#expand2(String, java.util.Map)}.
	 */
	@Test
	public final void testExpand2() {
		
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.append(
				"$${one}=${one},$${two}=${two},$${three}=${three}\n");
		stringBuilder.append("Operating System: ${os.name}\n");
		stringBuilder.append("java.lang implementation version: ").append(
				"${java.lang.implVersion}\n");
		stringBuilder.append("GNU long option assignment operator: ").append(
				"${GNU_LONG.assignmentOperator}\n");

		Map<String, String> map = new HashMap<String, String>();
		map.put("one", "1");
		map.put("two", "2");
		map.put("three", "3");
		
		StringBuilder expectedBuilder = new StringBuilder();
		expectedBuilder.append("${one}=1,${two}=2,${three}=3\n");
		expectedBuilder.append("Operating System: ").append(
				System.getProperty("os.name")).append('\n');
		expectedBuilder.append("java.lang implementation version: ").append(
				"${java.lang.implVersion}\n");
		expectedBuilder.append("GNU long option assignment operator: ").append(
				"${GNU_LONG.assignmentOperator}\n");
		
		assertEquals(
				expectedBuilder.toString(), 
				Util.expand2(stringBuilder.toString(), map));
	}

	/**
	 * Test method for {@link org.climax.Util#expand3(String, java.util.Map)}.
	 */
	@Test
	public final void testExpand3() {
		
		AbstractFactory.getDefault().setPackages(
				Arrays.asList(Package.getPackages()));
		
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.append(
				"$${one}=${one},$${two}=${two},$${three}=${three}\n");
		stringBuilder.append("Operating System: ${os.name}\n");
		stringBuilder.append("java.lang implementation version: ").append(
				"${java.lang.implVersion}\n");
		stringBuilder.append("GNU long option assignment operator: ").append(
				"${GNU_LONG.assignmentOperator}\n");

		Map<String, String> map = new HashMap<String, String>();
		map.put("one", "1");
		map.put("two", "2");
		map.put("three", "3");
		
		StringBuilder expectedBuilder = new StringBuilder();
		expectedBuilder.append("${one}=1,${two}=2,${three}=3\n");
		expectedBuilder.append("Operating System: ").append(
				System.getProperty("os.name")).append('\n');
		expectedBuilder.append("java.lang implementation version: ").append(
				Package.getPackage("java.lang").getImplementationVersion())
				.append('\n');
		expectedBuilder.append("GNU long option assignment operator: ").append(
				"${GNU_LONG.assignmentOperator}\n");
		
		assertEquals(
				expectedBuilder.toString(), 
				Util.expand3(stringBuilder.toString(), map));
	}

	/**
	 * Test method for {@link org.climax.Util#expand4(String, java.util.Map)}.
	 */
	@Test
	public final void testExpand4() {
		
		AbstractFactory.getDefault().setPackages(
				Arrays.asList(Package.getPackages()));
		
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.append(
				"$${one}=${one},$${two}=${two},$${three}=${three}\n");
		stringBuilder.append("Operating System: ${os.name}\n");
		stringBuilder.append("java.lang implementation version: ").append(
				"${java.lang.implVersion}\n");
		stringBuilder.append("GNU long option assignment operator: ").append(
				"${GNU_LONG.assignmentOperator}\n");

		Map<String, String> map = new HashMap<String, String>();
		map.put("one", "1");
		map.put("two", "2");
		map.put("three", "3");
		
		StringBuilder expectedBuilder = new StringBuilder();
		expectedBuilder.append("${one}=1,${two}=2,${three}=3\n");
		expectedBuilder.append("Operating System: ").append(
				System.getProperty("os.name")).append('\n');
		expectedBuilder.append("java.lang implementation version: ").append(
				Package.getPackage("java.lang").getImplementationVersion())
				.append('\n');
		expectedBuilder.append("GNU long option assignment operator: ").append(
				OptionType.GNU_LONG.getAssignmentOperator()).append('\n');
		
		assertEquals(
				expectedBuilder.toString(), 
				Util.expand4(stringBuilder.toString(), map));
	}

}
